# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/gcs_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as src_dot_ray_dot_protobuf_dot_common__pb2
from . import gcs_pb2 as src_dot_ray_dot_protobuf_dot_gcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='src/ray/protobuf/gcs_service.proto',
  package='ray.rpc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"src/ray/protobuf/gcs_service.proto\x12\x07ray.rpc\x1a\x1dsrc/ray/protobuf/common.proto\x1a\x1asrc/ray/protobuf/gcs.proto\":\n\rAddJobRequest\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x15.ray.rpc.JobTableDataR\x04\x64\x61ta\"9\n\x0b\x41\x64\x64JobReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"/\n\x16MarkJobFinishedRequest\x12\x15\n\x06job_id\x18\x01 \x01(\x0cR\x05jobId\"B\n\x14MarkJobFinishedReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x16\n\x14GetAllJobInfoRequest\"{\n\x12GetAllJobInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x39\n\rjob_info_list\x18\x02 \x03(\x0b\x32\x15.ray.rpc.JobTableDataR\x0bjobInfoList\"M\n\x15ReportJobErrorRequest\x12\x34\n\tjob_error\x18\x01 \x01(\x0b\x32\x17.ray.rpc.ErrorTableDataR\x08jobError\"A\n\x13ReportJobErrorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x15\n\x13GetNextJobIDRequest\"V\n\x11GetNextJobIDReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x15\n\x06job_id\x18\x02 \x01(\x05R\x05jobId\"D\n\x13GetActorInfoRequest\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x82\x01\n\x11GetActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"S\n\x18GetNamedActorInfoRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rray_namespace\x18\x02 \x01(\tR\x0crayNamespace\"\x87\x01\n\x16GetNamedActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x01(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"d\n\x16ListNamedActorsRequest\x12%\n\x0e\x61ll_namespaces\x18\x01 \x01(\x08R\rallNamespaces\x12#\n\rray_namespace\x18\x02 \x01(\tR\x0crayNamespace\"\x87\x01\n\x14ListNamedActorsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x43\n\x11named_actors_list\x18\x02 \x03(\x0b\x32\x17.ray.rpc.NamedActorInfoR\x0fnamedActorsList\">\n\x16GetAllActorInfoRequest\x12$\n\x0eshow_dead_jobs\x18\x01 \x01(\x08R\x0cshowDeadJobs\"\x85\x01\n\x14GetAllActorInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x41\n\x10\x61\x63tor_table_data\x18\x02 \x03(\x0b\x32\x17.ray.rpc.ActorTableDataR\x0e\x61\x63torTableData\"q\n\x16KillActorViaGcsRequest\x12\x19\n\x08\x61\x63tor_id\x18\x01 \x01(\x0cR\x07\x61\x63torId\x12\x1d\n\nforce_kill\x18\x02 \x01(\x08R\tforceKill\x12\x1d\n\nno_restart\x18\x03 \x01(\x08R\tnoRestart\"B\n\x14KillActorViaGcsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"H\n\x13RegisterNodeRequest\x12\x31\n\tnode_info\x18\x01 \x01(\x0b\x32\x14.ray.rpc.GcsNodeInfoR\x08nodeInfo\"?\n\x11RegisterNodeReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"0\n\x15UnregisterNodeRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"A\n\x13UnregisterNodeReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x17\n\x15GetAllNodeInfoRequest\"}\n\x13GetAllNodeInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12:\n\x0enode_info_list\x18\x02 \x03(\x0b\x32\x14.ray.rpc.GcsNodeInfoR\x0cnodeInfoList\"S\n\x16ReportHeartbeatRequest\x12\x39\n\theartbeat\x18\x01 \x01(\x0b\x32\x1b.ray.rpc.HeartbeatTableDataR\theartbeat\"B\n\x14ReportHeartbeatReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"%\n\x11\x43heckAliveRequest\x12\x10\n\x03seq\x18\x01 \x01(\x05R\x03seq\"O\n\x0f\x43heckAliveReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x10\n\x03seq\x18\x02 \x01(\x05R\x03seq\"\x1a\n\x18GetInternalConfigRequest\"\\\n\x16GetInternalConfigReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x16\n\x06\x63onfig\x18\x02 \x01(\tR\x06\x63onfig\".\n\x13GetResourcesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\"\xe2\x01\n\x11GetResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12G\n\tresources\x18\x02 \x03(\x0b\x32).ray.rpc.GetResourcesReply.ResourcesEntryR\tresources\x1aX\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.ResourceTableDataR\x05value:\x02\x38\x01\"\xd9\x01\n\x16UpdateResourcesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12L\n\tresources\x18\x02 \x03(\x0b\x32..ray.rpc.UpdateResourcesRequest.ResourcesEntryR\tresources\x1aX\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.ResourceTableDataR\x05value:\x02\x38\x01\"B\n\x14UpdateResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"_\n\x16\x44\x65leteResourcesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\x0cR\x06nodeId\x12,\n\x12resource_name_list\x18\x02 \x03(\tR\x10resourceNameList\"B\n\x14\x44\x65leteResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"!\n\x1fGetAllAvailableResourcesRequest\"\x8f\x01\n\x1dGetAllAvailableResourcesReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x42\n\x0eresources_list\x18\x02 \x03(\x0b\x32\x1b.ray.rpc.AvailableResourcesR\rresourcesList\"R\n\x1aReportResourceUsageRequest\x12\x34\n\tresources\x18\x01 \x01(\x0b\x32\x16.ray.rpc.ResourcesDataR\tresources\"F\n\x18ReportResourceUsageReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"8\n\x19GetObjectLocationsRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\"\x87\x01\n\x17GetObjectLocationsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12@\n\rlocation_info\x18\x02 \x01(\x0b\x32\x1b.ray.rpc.ObjectLocationInfoR\x0clocationInfo\"\x1e\n\x1cGetAllObjectLocationsRequest\"\xa0\x01\n\x1aGetAllObjectLocationsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12V\n\x19object_location_info_list\x18\x02 \x03(\x0b\x32\x1b.ray.rpc.ObjectLocationInfoR\x16objectLocationInfoList\"\xad\x01\n\x18\x41\x64\x64ObjectLocationRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x17\n\x07node_id\x18\x02 \x01(\x0cR\x06nodeId\x12\x1f\n\x0bspilled_url\x18\x03 \x01(\tR\nspilledUrl\x12&\n\x0fspilled_node_id\x18\x04 \x01(\x0cR\rspilledNodeId\x12\x12\n\x04size\x18\x05 \x01(\x04R\x04size\"D\n\x16\x41\x64\x64ObjectLocationReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"F\n\x18\x41\x64\x64ObjectSpilledUrlReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"S\n\x1bRemoveObjectLocationRequest\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x17\n\x07node_id\x18\x02 \x01(\x0cR\x06nodeId\"G\n\x19RemoveObjectLocationReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"E\n\x0e\x41\x64\x64TaskRequest\x12\x33\n\ttask_data\x18\x01 \x01(\x0b\x32\x16.ray.rpc.TaskTableDataR\x08taskData\":\n\x0c\x41\x64\x64TaskReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\")\n\x0eGetTaskRequest\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\"o\n\x0cGetTaskReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x33\n\ttask_data\x18\x02 \x01(\x0b\x32\x16.ray.rpc.TaskTableDataR\x08taskData\"U\n\x13\x41\x64\x64TaskLeaseRequest\x12>\n\x0ftask_lease_data\x18\x01 \x01(\x0b\x32\x16.ray.rpc.TaskLeaseDataR\rtaskLeaseData\"?\n\x11\x41\x64\x64TaskLeaseReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\".\n\x13GetTaskLeaseRequest\x12\x17\n\x07task_id\x18\x01 \x01(\x0cR\x06taskId\"\x7f\n\x11GetTaskLeaseReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12>\n\x0ftask_lease_data\x18\x02 \x01(\x0b\x32\x16.ray.rpc.TaskLeaseDataR\rtaskLeaseData\"t\n AttemptTaskReconstructionRequest\x12P\n\x13task_reconstruction\x18\x01 \x01(\x0b\x32\x1f.ray.rpc.TaskReconstructionDataR\x12taskReconstruction\"L\n\x1e\x41ttemptTaskReconstructionReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"U\n\x15\x41\x64\x64ProfileDataRequest\x12<\n\x0cprofile_data\x18\x01 \x01(\x0b\x32\x19.ray.rpc.ProfileTableDataR\x0bprofileData\"A\n\x13\x41\x64\x64ProfileDataReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"\x1a\n\x18GetAllProfileInfoRequest\"\x8b\x01\n\x16GetAllProfileInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x45\n\x11profile_info_list\x18\x02 \x03(\x0b\x32\x19.ray.rpc.ProfileTableDataR\x0fprofileInfoList\"]\n\x1aReportWorkerFailureRequest\x12?\n\x0eworker_failure\x18\x01 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\rworkerFailure\"F\n\x18ReportWorkerFailureReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"3\n\x14GetWorkerInfoRequest\x12\x1b\n\tworker_id\x18\x01 \x01(\x0cR\x08workerId\"\x86\x01\n\x12GetWorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x44\n\x11worker_table_data\x18\x02 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\x0fworkerTableData\"\x19\n\x17GetAllWorkerInfoRequest\"\x89\x01\n\x15GetAllWorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x44\n\x11worker_table_data\x18\x02 \x03(\x0b\x32\x18.ray.rpc.WorkerTableDataR\x0fworkerTableData\"Q\n\x14\x41\x64\x64WorkerInfoRequest\x12\x39\n\x0bworker_data\x18\x01 \x01(\x0b\x32\x18.ray.rpc.WorkerTableDataR\nworkerData\"@\n\x12\x41\x64\x64WorkerInfoReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"D\n\x12\x43reateActorRequest\x12.\n\ttask_spec\x18\x01 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\">\n\x10\x43reateActorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"F\n\x14RegisterActorRequest\x12.\n\ttask_spec\x18\x01 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\"@\n\x12RegisterActorReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"l\n\x1b\x43reatePlacementGroupRequest\x12M\n\x14placement_group_spec\x18\x01 \x01(\x0b\x32\x1b.ray.rpc.PlacementGroupSpecR\x12placementGroupSpec\"G\n\x19\x43reatePlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"K\n\x1bRemovePlacementGroupRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"G\n\x19RemovePlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"H\n\x18GetPlacementGroupRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"\xa3\x01\n\x16GetPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x01(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\"\x1d\n\x1bGetAllPlacementGroupRequest\"\xa6\x01\n\x19GetAllPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x03(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\"S\n#WaitPlacementGroupUntilReadyRequest\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\"O\n!WaitPlacementGroupUntilReadyReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\"X\n\x1dGetNamedPlacementGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12#\n\rray_namespace\x18\x02 \x01(\tR\x0crayNamespace\"\xa8\x01\n\x1bGetNamedPlacementGroupReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12]\n\x1aplacement_group_table_data\x18\x02 \x01(\x0b\x32 .ray.rpc.PlacementGroupTableDataR\x17placementGroupTableData\"(\n\x14InternalKVGetRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\"V\n\x12InternalKVGetReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\"\\\n\x14InternalKVPutRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\x12\x1c\n\toverwrite\x18\x03 \x01(\x08R\toverwrite\"]\n\x12InternalKVPutReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x1b\n\tadded_num\x18\x02 \x01(\x05R\x08\x61\x64\x64\x65\x64Num\"(\n\x14InternalKVDelRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\"a\n\x12InternalKVDelReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x1f\n\x0b\x64\x65leted_num\x18\x02 \x01(\x05R\ndeletedNum\"+\n\x17InternalKVExistsRequest\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\"[\n\x15InternalKVExistsReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x16\n\x06\x65xists\x18\x02 \x01(\x08R\x06\x65xists\"/\n\x15InternalKVKeysRequest\x12\x16\n\x06prefix\x18\x01 \x01(\x0cR\x06prefix\"[\n\x13InternalKVKeysReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12\x18\n\x07results\x18\x02 \x03(\x0cR\x07results\"\x1c\n\x1aGetAllResourceUsageRequest\"\x97\x01\n\x18GetAllResourceUsageReply\x12*\n\x06status\x18\x01 \x01(\x0b\x32\x12.ray.rpc.GcsStatusR\x06status\x12O\n\x13resource_usage_data\x18\x02 \x01(\x0b\x32\x1f.ray.rpc.ResourceUsageBatchDataR\x11resourceUsageData\"9\n\tGcsStatus\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message*C\n\x15GcsServiceFailureType\x12\x12\n\x0eRPC_DISCONNECT\x10\x00\x12\x16\n\x12GCS_SERVER_RESTART\x10\x01\x32\x85\x03\n\x11JobInfoGcsService\x12\x36\n\x06\x41\x64\x64Job\x12\x16.ray.rpc.AddJobRequest\x1a\x14.ray.rpc.AddJobReply\x12Q\n\x0fMarkJobFinished\x12\x1f.ray.rpc.MarkJobFinishedRequest\x1a\x1d.ray.rpc.MarkJobFinishedReply\x12K\n\rGetAllJobInfo\x12\x1d.ray.rpc.GetAllJobInfoRequest\x1a\x1b.ray.rpc.GetAllJobInfoReply\x12N\n\x0eReportJobError\x12\x1e.ray.rpc.ReportJobErrorRequest\x1a\x1c.ray.rpc.ReportJobErrorReply\x12H\n\x0cGetNextJobID\x12\x1c.ray.rpc.GetNextJobIDRequest\x1a\x1a.ray.rpc.GetNextJobIDReply2\xc5\x04\n\x13\x41\x63torInfoGcsService\x12K\n\rRegisterActor\x12\x1d.ray.rpc.RegisterActorRequest\x1a\x1b.ray.rpc.RegisterActorReply\x12\x45\n\x0b\x43reateActor\x12\x1b.ray.rpc.CreateActorRequest\x1a\x19.ray.rpc.CreateActorReply\x12H\n\x0cGetActorInfo\x12\x1c.ray.rpc.GetActorInfoRequest\x1a\x1a.ray.rpc.GetActorInfoReply\x12W\n\x11GetNamedActorInfo\x12!.ray.rpc.GetNamedActorInfoRequest\x1a\x1f.ray.rpc.GetNamedActorInfoReply\x12Q\n\x0fListNamedActors\x12\x1f.ray.rpc.ListNamedActorsRequest\x1a\x1d.ray.rpc.ListNamedActorsReply\x12Q\n\x0fGetAllActorInfo\x12\x1f.ray.rpc.GetAllActorInfoRequest\x1a\x1d.ray.rpc.GetAllActorInfoReply\x12Q\n\x0fKillActorViaGcs\x12\x1f.ray.rpc.KillActorViaGcsRequest\x1a\x1d.ray.rpc.KillActorViaGcsReply2\xd7\x02\n\x12NodeInfoGcsService\x12H\n\x0cRegisterNode\x12\x1c.ray.rpc.RegisterNodeRequest\x1a\x1a.ray.rpc.RegisterNodeReply\x12N\n\x0eUnregisterNode\x12\x1e.ray.rpc.UnregisterNodeRequest\x1a\x1c.ray.rpc.UnregisterNodeReply\x12N\n\x0eGetAllNodeInfo\x12\x1e.ray.rpc.GetAllNodeInfoRequest\x1a\x1c.ray.rpc.GetAllNodeInfoReply\x12W\n\x11GetInternalConfig\x12!.ray.rpc.GetInternalConfigRequest\x1a\x1f.ray.rpc.GetInternalConfigReply2\xb0\x01\n\x17HeartbeatInfoGcsService\x12Q\n\x0fReportHeartbeat\x12\x1f.ray.rpc.ReportHeartbeatRequest\x1a\x1d.ray.rpc.ReportHeartbeatReply\x12\x42\n\nCheckAlive\x12\x1a.ray.rpc.CheckAliveRequest\x1a\x18.ray.rpc.CheckAliveReply2\x92\x03\n\x14ObjectInfoGcsService\x12Z\n\x12GetObjectLocations\x12\".ray.rpc.GetObjectLocationsRequest\x1a .ray.rpc.GetObjectLocationsReply\x12\x63\n\x15GetAllObjectLocations\x12%.ray.rpc.GetAllObjectLocationsRequest\x1a#.ray.rpc.GetAllObjectLocationsReply\x12W\n\x11\x41\x64\x64ObjectLocation\x12!.ray.rpc.AddObjectLocationRequest\x1a\x1f.ray.rpc.AddObjectLocationReply\x12`\n\x14RemoveObjectLocation\x12$.ray.rpc.RemoveObjectLocationRequest\x1a\".ray.rpc.RemoveObjectLocationReply2\x8f\x03\n\x12TaskInfoGcsService\x12\x39\n\x07\x41\x64\x64Task\x12\x17.ray.rpc.AddTaskRequest\x1a\x15.ray.rpc.AddTaskReply\x12\x39\n\x07GetTask\x12\x17.ray.rpc.GetTaskRequest\x1a\x15.ray.rpc.GetTaskReply\x12H\n\x0c\x41\x64\x64TaskLease\x12\x1c.ray.rpc.AddTaskLeaseRequest\x1a\x1a.ray.rpc.AddTaskLeaseReply\x12H\n\x0cGetTaskLease\x12\x1c.ray.rpc.GetTaskLeaseRequest\x1a\x1a.ray.rpc.GetTaskLeaseReply\x12o\n\x19\x41ttemptTaskReconstruction\x12).ray.rpc.AttemptTaskReconstructionRequest\x1a\'.ray.rpc.AttemptTaskReconstructionReply2\xba\x01\n\x0fStatsGcsService\x12N\n\x0e\x41\x64\x64ProfileData\x12\x1e.ray.rpc.AddProfileDataRequest\x1a\x1c.ray.rpc.AddProfileDataReply\x12W\n\x11GetAllProfileInfo\x12!.ray.rpc.GetAllProfileInfoRequest\x1a\x1f.ray.rpc.GetAllProfileInfoReply2\xe5\x02\n\x14WorkerInfoGcsService\x12]\n\x13ReportWorkerFailure\x12#.ray.rpc.ReportWorkerFailureRequest\x1a!.ray.rpc.ReportWorkerFailureReply\x12K\n\rGetWorkerInfo\x12\x1d.ray.rpc.GetWorkerInfoRequest\x1a\x1b.ray.rpc.GetWorkerInfoReply\x12T\n\x10GetAllWorkerInfo\x12 .ray.rpc.GetAllWorkerInfoRequest\x1a\x1e.ray.rpc.GetAllWorkerInfoReply\x12K\n\rAddWorkerInfo\x12\x1d.ray.rpc.AddWorkerInfoRequest\x1a\x1b.ray.rpc.AddWorkerInfoReply2\xff\x04\n\x1cPlacementGroupInfoGcsService\x12`\n\x14\x43reatePlacementGroup\x12$.ray.rpc.CreatePlacementGroupRequest\x1a\".ray.rpc.CreatePlacementGroupReply\x12`\n\x14RemovePlacementGroup\x12$.ray.rpc.RemovePlacementGroupRequest\x1a\".ray.rpc.RemovePlacementGroupReply\x12W\n\x11GetPlacementGroup\x12!.ray.rpc.GetPlacementGroupRequest\x1a\x1f.ray.rpc.GetPlacementGroupReply\x12\x66\n\x16GetNamedPlacementGroup\x12&.ray.rpc.GetNamedPlacementGroupRequest\x1a$.ray.rpc.GetNamedPlacementGroupReply\x12`\n\x14GetAllPlacementGroup\x12$.ray.rpc.GetAllPlacementGroupRequest\x1a\".ray.rpc.GetAllPlacementGroupReply\x12x\n\x1cWaitPlacementGroupUntilReady\x12,.ray.rpc.WaitPlacementGroupUntilReadyRequest\x1a*.ray.rpc.WaitPlacementGroupUntilReadyReply2\xa3\x03\n\x14InternalKVGcsService\x12K\n\rInternalKVGet\x12\x1d.ray.rpc.InternalKVGetRequest\x1a\x1b.ray.rpc.InternalKVGetReply\x12K\n\rInternalKVPut\x12\x1d.ray.rpc.InternalKVPutRequest\x1a\x1b.ray.rpc.InternalKVPutReply\x12K\n\rInternalKVDel\x12\x1d.ray.rpc.InternalKVDelRequest\x1a\x1b.ray.rpc.InternalKVDelReply\x12T\n\x10InternalKVExists\x12 .ray.rpc.InternalKVExistsRequest\x1a\x1e.ray.rpc.InternalKVExistsReply\x12N\n\x0eInternalKVKeys\x12\x1e.ray.rpc.InternalKVKeysRequest\x1a\x1c.ray.rpc.InternalKVKeysReply2\xb8\x04\n\x1aNodeResourceInfoGcsService\x12H\n\x0cGetResources\x12\x1c.ray.rpc.GetResourcesRequest\x1a\x1a.ray.rpc.GetResourcesReply\x12Q\n\x0fUpdateResources\x12\x1f.ray.rpc.UpdateResourcesRequest\x1a\x1d.ray.rpc.UpdateResourcesReply\x12Q\n\x0f\x44\x65leteResources\x12\x1f.ray.rpc.DeleteResourcesRequest\x1a\x1d.ray.rpc.DeleteResourcesReply\x12l\n\x18GetAllAvailableResources\x12(.ray.rpc.GetAllAvailableResourcesRequest\x1a&.ray.rpc.GetAllAvailableResourcesReply\x12]\n\x13ReportResourceUsage\x12#.ray.rpc.ReportResourceUsageRequest\x1a!.ray.rpc.ReportResourceUsageReply\x12]\n\x13GetAllResourceUsage\x12#.ray.rpc.GetAllResourceUsageRequest\x1a!.ray.rpc.GetAllResourceUsageReplyb\x06proto3'
  ,
  dependencies=[src_dot_ray_dot_protobuf_dot_common__pb2.DESCRIPTOR,src_dot_ray_dot_protobuf_dot_gcs__pb2.DESCRIPTOR,])

_GCSSERVICEFAILURETYPE = _descriptor.EnumDescriptor(
  name='GcsServiceFailureType',
  full_name='ray.rpc.GcsServiceFailureType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RPC_DISCONNECT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GCS_SERVER_RESTART', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8798,
  serialized_end=8865,
)
_sym_db.RegisterEnumDescriptor(_GCSSERVICEFAILURETYPE)

GcsServiceFailureType = enum_type_wrapper.EnumTypeWrapper(_GCSSERVICEFAILURETYPE)
RPC_DISCONNECT = 0
GCS_SERVER_RESTART = 1



_ADDJOBREQUEST = _descriptor.Descriptor(
  name='AddJobRequest',
  full_name='ray.rpc.AddJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.AddJobRequest.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=164,
)


_ADDJOBREPLY = _descriptor.Descriptor(
  name='AddJobReply',
  full_name='ray.rpc.AddJobReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddJobReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=223,
)


_MARKJOBFINISHEDREQUEST = _descriptor.Descriptor(
  name='MarkJobFinishedRequest',
  full_name='ray.rpc.MarkJobFinishedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.MarkJobFinishedRequest.job_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=272,
)


_MARKJOBFINISHEDREPLY = _descriptor.Descriptor(
  name='MarkJobFinishedReply',
  full_name='ray.rpc.MarkJobFinishedReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.MarkJobFinishedReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=340,
)


_GETALLJOBINFOREQUEST = _descriptor.Descriptor(
  name='GetAllJobInfoRequest',
  full_name='ray.rpc.GetAllJobInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=364,
)


_GETALLJOBINFOREPLY = _descriptor.Descriptor(
  name='GetAllJobInfoReply',
  full_name='ray.rpc.GetAllJobInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllJobInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_info_list', full_name='ray.rpc.GetAllJobInfoReply.job_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobInfoList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=489,
)


_REPORTJOBERRORREQUEST = _descriptor.Descriptor(
  name='ReportJobErrorRequest',
  full_name='ray.rpc.ReportJobErrorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_error', full_name='ray.rpc.ReportJobErrorRequest.job_error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobError', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=568,
)


_REPORTJOBERRORREPLY = _descriptor.Descriptor(
  name='ReportJobErrorReply',
  full_name='ray.rpc.ReportJobErrorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ReportJobErrorReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=635,
)


_GETNEXTJOBIDREQUEST = _descriptor.Descriptor(
  name='GetNextJobIDRequest',
  full_name='ray.rpc.GetNextJobIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=658,
)


_GETNEXTJOBIDREPLY = _descriptor.Descriptor(
  name='GetNextJobIDReply',
  full_name='ray.rpc.GetNextJobIDReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetNextJobIDReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.GetNextJobIDReply.job_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=746,
)


_GETACTORINFOREQUEST = _descriptor.Descriptor(
  name='GetActorInfoRequest',
  full_name='ray.rpc.GetActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.GetActorInfoRequest.actor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.GetActorInfoRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=816,
)


_GETACTORINFOREPLY = _descriptor.Descriptor(
  name='GetActorInfoReply',
  full_name='ray.rpc.GetActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.GetActorInfoReply.actor_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=949,
)


_GETNAMEDACTORINFOREQUEST = _descriptor.Descriptor(
  name='GetNamedActorInfoRequest',
  full_name='ray.rpc.GetNamedActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.GetNamedActorInfoRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_namespace', full_name='ray.rpc.GetNamedActorInfoRequest.ray_namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayNamespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=1034,
)


_GETNAMEDACTORINFOREPLY = _descriptor.Descriptor(
  name='GetNamedActorInfoReply',
  full_name='ray.rpc.GetNamedActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetNamedActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.GetNamedActorInfoReply.actor_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1172,
)


_LISTNAMEDACTORSREQUEST = _descriptor.Descriptor(
  name='ListNamedActorsRequest',
  full_name='ray.rpc.ListNamedActorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all_namespaces', full_name='ray.rpc.ListNamedActorsRequest.all_namespaces', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='allNamespaces', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_namespace', full_name='ray.rpc.ListNamedActorsRequest.ray_namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayNamespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1274,
)


_LISTNAMEDACTORSREPLY = _descriptor.Descriptor(
  name='ListNamedActorsReply',
  full_name='ray.rpc.ListNamedActorsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ListNamedActorsReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_actors_list', full_name='ray.rpc.ListNamedActorsReply.named_actors_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='namedActorsList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1277,
  serialized_end=1412,
)


_GETALLACTORINFOREQUEST = _descriptor.Descriptor(
  name='GetAllActorInfoRequest',
  full_name='ray.rpc.GetAllActorInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='show_dead_jobs', full_name='ray.rpc.GetAllActorInfoRequest.show_dead_jobs', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='showDeadJobs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1414,
  serialized_end=1476,
)


_GETALLACTORINFOREPLY = _descriptor.Descriptor(
  name='GetAllActorInfoReply',
  full_name='ray.rpc.GetAllActorInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllActorInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_table_data', full_name='ray.rpc.GetAllActorInfoReply.actor_table_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1479,
  serialized_end=1612,
)


_KILLACTORVIAGCSREQUEST = _descriptor.Descriptor(
  name='KillActorViaGcsRequest',
  full_name='ray.rpc.KillActorViaGcsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.KillActorViaGcsRequest.actor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force_kill', full_name='ray.rpc.KillActorViaGcsRequest.force_kill', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='forceKill', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_restart', full_name='ray.rpc.KillActorViaGcsRequest.no_restart', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='noRestart', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1614,
  serialized_end=1727,
)


_KILLACTORVIAGCSREPLY = _descriptor.Descriptor(
  name='KillActorViaGcsReply',
  full_name='ray.rpc.KillActorViaGcsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.KillActorViaGcsReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1795,
)


_REGISTERNODEREQUEST = _descriptor.Descriptor(
  name='RegisterNodeRequest',
  full_name='ray.rpc.RegisterNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_info', full_name='ray.rpc.RegisterNodeRequest.node_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=1869,
)


_REGISTERNODEREPLY = _descriptor.Descriptor(
  name='RegisterNodeReply',
  full_name='ray.rpc.RegisterNodeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RegisterNodeReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1871,
  serialized_end=1934,
)


_UNREGISTERNODEREQUEST = _descriptor.Descriptor(
  name='UnregisterNodeRequest',
  full_name='ray.rpc.UnregisterNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.UnregisterNodeRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1936,
  serialized_end=1984,
)


_UNREGISTERNODEREPLY = _descriptor.Descriptor(
  name='UnregisterNodeReply',
  full_name='ray.rpc.UnregisterNodeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.UnregisterNodeReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2051,
)


_GETALLNODEINFOREQUEST = _descriptor.Descriptor(
  name='GetAllNodeInfoRequest',
  full_name='ray.rpc.GetAllNodeInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2076,
)


_GETALLNODEINFOREPLY = _descriptor.Descriptor(
  name='GetAllNodeInfoReply',
  full_name='ray.rpc.GetAllNodeInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllNodeInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_info_list', full_name='ray.rpc.GetAllNodeInfoReply.node_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeInfoList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2203,
)


_REPORTHEARTBEATREQUEST = _descriptor.Descriptor(
  name='ReportHeartbeatRequest',
  full_name='ray.rpc.ReportHeartbeatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heartbeat', full_name='ray.rpc.ReportHeartbeatRequest.heartbeat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='heartbeat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2205,
  serialized_end=2288,
)


_REPORTHEARTBEATREPLY = _descriptor.Descriptor(
  name='ReportHeartbeatReply',
  full_name='ray.rpc.ReportHeartbeatReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ReportHeartbeatReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2290,
  serialized_end=2356,
)


_CHECKALIVEREQUEST = _descriptor.Descriptor(
  name='CheckAliveRequest',
  full_name='ray.rpc.CheckAliveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='ray.rpc.CheckAliveRequest.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='seq', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2358,
  serialized_end=2395,
)


_CHECKALIVEREPLY = _descriptor.Descriptor(
  name='CheckAliveReply',
  full_name='ray.rpc.CheckAliveReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.CheckAliveReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='ray.rpc.CheckAliveReply.seq', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='seq', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2397,
  serialized_end=2476,
)


_GETINTERNALCONFIGREQUEST = _descriptor.Descriptor(
  name='GetInternalConfigRequest',
  full_name='ray.rpc.GetInternalConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2478,
  serialized_end=2504,
)


_GETINTERNALCONFIGREPLY = _descriptor.Descriptor(
  name='GetInternalConfigReply',
  full_name='ray.rpc.GetInternalConfigReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetInternalConfigReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='ray.rpc.GetInternalConfigReply.config', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='config', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2506,
  serialized_end=2598,
)


_GETRESOURCESREQUEST = _descriptor.Descriptor(
  name='GetResourcesRequest',
  full_name='ray.rpc.GetResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.GetResourcesRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2600,
  serialized_end=2646,
)


_GETRESOURCESREPLY_RESOURCESENTRY = _descriptor.Descriptor(
  name='ResourcesEntry',
  full_name='ray.rpc.GetResourcesReply.ResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.GetResourcesReply.ResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.GetResourcesReply.ResourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2787,
  serialized_end=2875,
)

_GETRESOURCESREPLY = _descriptor.Descriptor(
  name='GetResourcesReply',
  full_name='ray.rpc.GetResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='ray.rpc.GetResourcesReply.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETRESOURCESREPLY_RESOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2649,
  serialized_end=2875,
)


_UPDATERESOURCESREQUEST_RESOURCESENTRY = _descriptor.Descriptor(
  name='ResourcesEntry',
  full_name='ray.rpc.UpdateResourcesRequest.ResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.UpdateResourcesRequest.ResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.UpdateResourcesRequest.ResourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2787,
  serialized_end=2875,
)

_UPDATERESOURCESREQUEST = _descriptor.Descriptor(
  name='UpdateResourcesRequest',
  full_name='ray.rpc.UpdateResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.UpdateResourcesRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='ray.rpc.UpdateResourcesRequest.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATERESOURCESREQUEST_RESOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2878,
  serialized_end=3095,
)


_UPDATERESOURCESREPLY = _descriptor.Descriptor(
  name='UpdateResourcesReply',
  full_name='ray.rpc.UpdateResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.UpdateResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3097,
  serialized_end=3163,
)


_DELETERESOURCESREQUEST = _descriptor.Descriptor(
  name='DeleteResourcesRequest',
  full_name='ray.rpc.DeleteResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.DeleteResourcesRequest.node_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_name_list', full_name='ray.rpc.DeleteResourcesRequest.resource_name_list', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceNameList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3165,
  serialized_end=3260,
)


_DELETERESOURCESREPLY = _descriptor.Descriptor(
  name='DeleteResourcesReply',
  full_name='ray.rpc.DeleteResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.DeleteResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3262,
  serialized_end=3328,
)


_GETALLAVAILABLERESOURCESREQUEST = _descriptor.Descriptor(
  name='GetAllAvailableResourcesRequest',
  full_name='ray.rpc.GetAllAvailableResourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3330,
  serialized_end=3363,
)


_GETALLAVAILABLERESOURCESREPLY = _descriptor.Descriptor(
  name='GetAllAvailableResourcesReply',
  full_name='ray.rpc.GetAllAvailableResourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllAvailableResourcesReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_list', full_name='ray.rpc.GetAllAvailableResourcesReply.resources_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourcesList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3366,
  serialized_end=3509,
)


_REPORTRESOURCEUSAGEREQUEST = _descriptor.Descriptor(
  name='ReportResourceUsageRequest',
  full_name='ray.rpc.ReportResourceUsageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='ray.rpc.ReportResourceUsageRequest.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3511,
  serialized_end=3593,
)


_REPORTRESOURCEUSAGEREPLY = _descriptor.Descriptor(
  name='ReportResourceUsageReply',
  full_name='ray.rpc.ReportResourceUsageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ReportResourceUsageReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3595,
  serialized_end=3665,
)


_GETOBJECTLOCATIONSREQUEST = _descriptor.Descriptor(
  name='GetObjectLocationsRequest',
  full_name='ray.rpc.GetObjectLocationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.GetObjectLocationsRequest.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3667,
  serialized_end=3723,
)


_GETOBJECTLOCATIONSREPLY = _descriptor.Descriptor(
  name='GetObjectLocationsReply',
  full_name='ray.rpc.GetObjectLocationsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetObjectLocationsReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location_info', full_name='ray.rpc.GetObjectLocationsReply.location_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='locationInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3726,
  serialized_end=3861,
)


_GETALLOBJECTLOCATIONSREQUEST = _descriptor.Descriptor(
  name='GetAllObjectLocationsRequest',
  full_name='ray.rpc.GetAllObjectLocationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3863,
  serialized_end=3893,
)


_GETALLOBJECTLOCATIONSREPLY = _descriptor.Descriptor(
  name='GetAllObjectLocationsReply',
  full_name='ray.rpc.GetAllObjectLocationsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllObjectLocationsReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_location_info_list', full_name='ray.rpc.GetAllObjectLocationsReply.object_location_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectLocationInfoList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3896,
  serialized_end=4056,
)


_ADDOBJECTLOCATIONREQUEST = _descriptor.Descriptor(
  name='AddObjectLocationRequest',
  full_name='ray.rpc.AddObjectLocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.AddObjectLocationRequest.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.AddObjectLocationRequest.node_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spilled_url', full_name='ray.rpc.AddObjectLocationRequest.spilled_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spilled_node_id', full_name='ray.rpc.AddObjectLocationRequest.spilled_node_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spilledNodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='ray.rpc.AddObjectLocationRequest.size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='size', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4059,
  serialized_end=4232,
)


_ADDOBJECTLOCATIONREPLY = _descriptor.Descriptor(
  name='AddObjectLocationReply',
  full_name='ray.rpc.AddObjectLocationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddObjectLocationReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4234,
  serialized_end=4302,
)


_ADDOBJECTSPILLEDURLREPLY = _descriptor.Descriptor(
  name='AddObjectSpilledUrlReply',
  full_name='ray.rpc.AddObjectSpilledUrlReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddObjectSpilledUrlReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4304,
  serialized_end=4374,
)


_REMOVEOBJECTLOCATIONREQUEST = _descriptor.Descriptor(
  name='RemoveObjectLocationRequest',
  full_name='ray.rpc.RemoveObjectLocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.RemoveObjectLocationRequest.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.RemoveObjectLocationRequest.node_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4376,
  serialized_end=4459,
)


_REMOVEOBJECTLOCATIONREPLY = _descriptor.Descriptor(
  name='RemoveObjectLocationReply',
  full_name='ray.rpc.RemoveObjectLocationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RemoveObjectLocationReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4461,
  serialized_end=4532,
)


_ADDTASKREQUEST = _descriptor.Descriptor(
  name='AddTaskRequest',
  full_name='ray.rpc.AddTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_data', full_name='ray.rpc.AddTaskRequest.task_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4534,
  serialized_end=4603,
)


_ADDTASKREPLY = _descriptor.Descriptor(
  name='AddTaskReply',
  full_name='ray.rpc.AddTaskReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddTaskReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4605,
  serialized_end=4663,
)


_GETTASKREQUEST = _descriptor.Descriptor(
  name='GetTaskRequest',
  full_name='ray.rpc.GetTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.GetTaskRequest.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4665,
  serialized_end=4706,
)


_GETTASKREPLY = _descriptor.Descriptor(
  name='GetTaskReply',
  full_name='ray.rpc.GetTaskReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetTaskReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_data', full_name='ray.rpc.GetTaskReply.task_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4708,
  serialized_end=4819,
)


_ADDTASKLEASEREQUEST = _descriptor.Descriptor(
  name='AddTaskLeaseRequest',
  full_name='ray.rpc.AddTaskLeaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_lease_data', full_name='ray.rpc.AddTaskLeaseRequest.task_lease_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskLeaseData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4821,
  serialized_end=4906,
)


_ADDTASKLEASEREPLY = _descriptor.Descriptor(
  name='AddTaskLeaseReply',
  full_name='ray.rpc.AddTaskLeaseReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddTaskLeaseReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4908,
  serialized_end=4971,
)


_GETTASKLEASEREQUEST = _descriptor.Descriptor(
  name='GetTaskLeaseRequest',
  full_name='ray.rpc.GetTaskLeaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.GetTaskLeaseRequest.task_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4973,
  serialized_end=5019,
)


_GETTASKLEASEREPLY = _descriptor.Descriptor(
  name='GetTaskLeaseReply',
  full_name='ray.rpc.GetTaskLeaseReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetTaskLeaseReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_lease_data', full_name='ray.rpc.GetTaskLeaseReply.task_lease_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskLeaseData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5021,
  serialized_end=5148,
)


_ATTEMPTTASKRECONSTRUCTIONREQUEST = _descriptor.Descriptor(
  name='AttemptTaskReconstructionRequest',
  full_name='ray.rpc.AttemptTaskReconstructionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_reconstruction', full_name='ray.rpc.AttemptTaskReconstructionRequest.task_reconstruction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskReconstruction', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5150,
  serialized_end=5266,
)


_ATTEMPTTASKRECONSTRUCTIONREPLY = _descriptor.Descriptor(
  name='AttemptTaskReconstructionReply',
  full_name='ray.rpc.AttemptTaskReconstructionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AttemptTaskReconstructionReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5268,
  serialized_end=5344,
)


_ADDPROFILEDATAREQUEST = _descriptor.Descriptor(
  name='AddProfileDataRequest',
  full_name='ray.rpc.AddProfileDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_data', full_name='ray.rpc.AddProfileDataRequest.profile_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='profileData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5346,
  serialized_end=5431,
)


_ADDPROFILEDATAREPLY = _descriptor.Descriptor(
  name='AddProfileDataReply',
  full_name='ray.rpc.AddProfileDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddProfileDataReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5433,
  serialized_end=5498,
)


_GETALLPROFILEINFOREQUEST = _descriptor.Descriptor(
  name='GetAllProfileInfoRequest',
  full_name='ray.rpc.GetAllProfileInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5500,
  serialized_end=5526,
)


_GETALLPROFILEINFOREPLY = _descriptor.Descriptor(
  name='GetAllProfileInfoReply',
  full_name='ray.rpc.GetAllProfileInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllProfileInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_info_list', full_name='ray.rpc.GetAllProfileInfoReply.profile_info_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='profileInfoList', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5529,
  serialized_end=5668,
)


_REPORTWORKERFAILUREREQUEST = _descriptor.Descriptor(
  name='ReportWorkerFailureRequest',
  full_name='ray.rpc.ReportWorkerFailureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_failure', full_name='ray.rpc.ReportWorkerFailureRequest.worker_failure', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerFailure', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5670,
  serialized_end=5763,
)


_REPORTWORKERFAILUREREPLY = _descriptor.Descriptor(
  name='ReportWorkerFailureReply',
  full_name='ray.rpc.ReportWorkerFailureReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.ReportWorkerFailureReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5765,
  serialized_end=5835,
)


_GETWORKERINFOREQUEST = _descriptor.Descriptor(
  name='GetWorkerInfoRequest',
  full_name='ray.rpc.GetWorkerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='ray.rpc.GetWorkerInfoRequest.worker_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5837,
  serialized_end=5888,
)


_GETWORKERINFOREPLY = _descriptor.Descriptor(
  name='GetWorkerInfoReply',
  full_name='ray.rpc.GetWorkerInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetWorkerInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_table_data', full_name='ray.rpc.GetWorkerInfoReply.worker_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5891,
  serialized_end=6025,
)


_GETALLWORKERINFOREQUEST = _descriptor.Descriptor(
  name='GetAllWorkerInfoRequest',
  full_name='ray.rpc.GetAllWorkerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6027,
  serialized_end=6052,
)


_GETALLWORKERINFOREPLY = _descriptor.Descriptor(
  name='GetAllWorkerInfoReply',
  full_name='ray.rpc.GetAllWorkerInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllWorkerInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_table_data', full_name='ray.rpc.GetAllWorkerInfoReply.worker_table_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6055,
  serialized_end=6192,
)


_ADDWORKERINFOREQUEST = _descriptor.Descriptor(
  name='AddWorkerInfoRequest',
  full_name='ray.rpc.AddWorkerInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_data', full_name='ray.rpc.AddWorkerInfoRequest.worker_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6194,
  serialized_end=6275,
)


_ADDWORKERINFOREPLY = _descriptor.Descriptor(
  name='AddWorkerInfoReply',
  full_name='ray.rpc.AddWorkerInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.AddWorkerInfoReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6277,
  serialized_end=6341,
)


_CREATEACTORREQUEST = _descriptor.Descriptor(
  name='CreateActorRequest',
  full_name='ray.rpc.CreateActorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_spec', full_name='ray.rpc.CreateActorRequest.task_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6343,
  serialized_end=6411,
)


_CREATEACTORREPLY = _descriptor.Descriptor(
  name='CreateActorReply',
  full_name='ray.rpc.CreateActorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.CreateActorReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6413,
  serialized_end=6475,
)


_REGISTERACTORREQUEST = _descriptor.Descriptor(
  name='RegisterActorRequest',
  full_name='ray.rpc.RegisterActorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_spec', full_name='ray.rpc.RegisterActorRequest.task_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6477,
  serialized_end=6547,
)


_REGISTERACTORREPLY = _descriptor.Descriptor(
  name='RegisterActorReply',
  full_name='ray.rpc.RegisterActorReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RegisterActorReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6549,
  serialized_end=6613,
)


_CREATEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='CreatePlacementGroupRequest',
  full_name='ray.rpc.CreatePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_spec', full_name='ray.rpc.CreatePlacementGroupRequest.placement_group_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6615,
  serialized_end=6723,
)


_CREATEPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='CreatePlacementGroupReply',
  full_name='ray.rpc.CreatePlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.CreatePlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6725,
  serialized_end=6796,
)


_REMOVEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='RemovePlacementGroupRequest',
  full_name='ray.rpc.RemovePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.RemovePlacementGroupRequest.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6798,
  serialized_end=6873,
)


_REMOVEPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='RemovePlacementGroupReply',
  full_name='ray.rpc.RemovePlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.RemovePlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6875,
  serialized_end=6946,
)


_GETPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='GetPlacementGroupRequest',
  full_name='ray.rpc.GetPlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.GetPlacementGroupRequest.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6948,
  serialized_end=7020,
)


_GETPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='GetPlacementGroupReply',
  full_name='ray.rpc.GetPlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetPlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group_table_data', full_name='ray.rpc.GetPlacementGroupReply.placement_group_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7023,
  serialized_end=7186,
)


_GETALLPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='GetAllPlacementGroupRequest',
  full_name='ray.rpc.GetAllPlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7188,
  serialized_end=7217,
)


_GETALLPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='GetAllPlacementGroupReply',
  full_name='ray.rpc.GetAllPlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllPlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group_table_data', full_name='ray.rpc.GetAllPlacementGroupReply.placement_group_table_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7220,
  serialized_end=7386,
)


_WAITPLACEMENTGROUPUNTILREADYREQUEST = _descriptor.Descriptor(
  name='WaitPlacementGroupUntilReadyRequest',
  full_name='ray.rpc.WaitPlacementGroupUntilReadyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.WaitPlacementGroupUntilReadyRequest.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7388,
  serialized_end=7471,
)


_WAITPLACEMENTGROUPUNTILREADYREPLY = _descriptor.Descriptor(
  name='WaitPlacementGroupUntilReadyReply',
  full_name='ray.rpc.WaitPlacementGroupUntilReadyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.WaitPlacementGroupUntilReadyReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7473,
  serialized_end=7552,
)


_GETNAMEDPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='GetNamedPlacementGroupRequest',
  full_name='ray.rpc.GetNamedPlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.GetNamedPlacementGroupRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ray_namespace', full_name='ray.rpc.GetNamedPlacementGroupRequest.ray_namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayNamespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7554,
  serialized_end=7642,
)


_GETNAMEDPLACEMENTGROUPREPLY = _descriptor.Descriptor(
  name='GetNamedPlacementGroupReply',
  full_name='ray.rpc.GetNamedPlacementGroupReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetNamedPlacementGroupReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group_table_data', full_name='ray.rpc.GetNamedPlacementGroupReply.placement_group_table_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupTableData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7645,
  serialized_end=7813,
)


_INTERNALKVGETREQUEST = _descriptor.Descriptor(
  name='InternalKVGetRequest',
  full_name='ray.rpc.InternalKVGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.InternalKVGetRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7815,
  serialized_end=7855,
)


_INTERNALKVGETREPLY = _descriptor.Descriptor(
  name='InternalKVGetReply',
  full_name='ray.rpc.InternalKVGetReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.InternalKVGetReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.InternalKVGetReply.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7857,
  serialized_end=7943,
)


_INTERNALKVPUTREQUEST = _descriptor.Descriptor(
  name='InternalKVPutRequest',
  full_name='ray.rpc.InternalKVPutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.InternalKVPutRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.InternalKVPutRequest.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='ray.rpc.InternalKVPutRequest.overwrite', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overwrite', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7945,
  serialized_end=8037,
)


_INTERNALKVPUTREPLY = _descriptor.Descriptor(
  name='InternalKVPutReply',
  full_name='ray.rpc.InternalKVPutReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.InternalKVPutReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='added_num', full_name='ray.rpc.InternalKVPutReply.added_num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='addedNum', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8039,
  serialized_end=8132,
)


_INTERNALKVDELREQUEST = _descriptor.Descriptor(
  name='InternalKVDelRequest',
  full_name='ray.rpc.InternalKVDelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.InternalKVDelRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8134,
  serialized_end=8174,
)


_INTERNALKVDELREPLY = _descriptor.Descriptor(
  name='InternalKVDelReply',
  full_name='ray.rpc.InternalKVDelReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.InternalKVDelReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_num', full_name='ray.rpc.InternalKVDelReply.deleted_num', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deletedNum', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8176,
  serialized_end=8273,
)


_INTERNALKVEXISTSREQUEST = _descriptor.Descriptor(
  name='InternalKVExistsRequest',
  full_name='ray.rpc.InternalKVExistsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.InternalKVExistsRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8275,
  serialized_end=8318,
)


_INTERNALKVEXISTSREPLY = _descriptor.Descriptor(
  name='InternalKVExistsReply',
  full_name='ray.rpc.InternalKVExistsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.InternalKVExistsReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exists', full_name='ray.rpc.InternalKVExistsReply.exists', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='exists', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8320,
  serialized_end=8411,
)


_INTERNALKVKEYSREQUEST = _descriptor.Descriptor(
  name='InternalKVKeysRequest',
  full_name='ray.rpc.InternalKVKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='ray.rpc.InternalKVKeysRequest.prefix', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='prefix', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8413,
  serialized_end=8460,
)


_INTERNALKVKEYSREPLY = _descriptor.Descriptor(
  name='InternalKVKeysReply',
  full_name='ray.rpc.InternalKVKeysReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.InternalKVKeysReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='results', full_name='ray.rpc.InternalKVKeysReply.results', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='results', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8462,
  serialized_end=8553,
)


_GETALLRESOURCEUSAGEREQUEST = _descriptor.Descriptor(
  name='GetAllResourceUsageRequest',
  full_name='ray.rpc.GetAllResourceUsageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8555,
  serialized_end=8583,
)


_GETALLRESOURCEUSAGEREPLY = _descriptor.Descriptor(
  name='GetAllResourceUsageReply',
  full_name='ray.rpc.GetAllResourceUsageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ray.rpc.GetAllResourceUsageReply.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_usage_data', full_name='ray.rpc.GetAllResourceUsageReply.resource_usage_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceUsageData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8586,
  serialized_end=8737,
)


_GCSSTATUS = _descriptor.Descriptor(
  name='GcsStatus',
  full_name='ray.rpc.GcsStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='ray.rpc.GcsStatus.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='ray.rpc.GcsStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8739,
  serialized_end=8796,
)

_ADDJOBREQUEST.fields_by_name['data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._JOBTABLEDATA
_ADDJOBREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_MARKJOBFINISHEDREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLJOBINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLJOBINFOREPLY.fields_by_name['job_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._JOBTABLEDATA
_REPORTJOBERRORREQUEST.fields_by_name['job_error'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ERRORTABLEDATA
_REPORTJOBERRORREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETNEXTJOBIDREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETACTORINFOREPLY.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_GETNAMEDACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETNAMEDACTORINFOREPLY.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_LISTNAMEDACTORSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_LISTNAMEDACTORSREPLY.fields_by_name['named_actors_list'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._NAMEDACTORINFO
_GETALLACTORINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLACTORINFOREPLY.fields_by_name['actor_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._ACTORTABLEDATA
_KILLACTORVIAGCSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REGISTERNODEREQUEST.fields_by_name['node_info'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._GCSNODEINFO
_REGISTERNODEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_UNREGISTERNODEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLNODEINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLNODEINFOREPLY.fields_by_name['node_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._GCSNODEINFO
_REPORTHEARTBEATREQUEST.fields_by_name['heartbeat'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._HEARTBEATTABLEDATA
_REPORTHEARTBEATREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_CHECKALIVEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETINTERNALCONFIGREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETRESOURCESREPLY_RESOURCESENTRY.fields_by_name['value'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCETABLEDATA
_GETRESOURCESREPLY_RESOURCESENTRY.containing_type = _GETRESOURCESREPLY
_GETRESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETRESOURCESREPLY.fields_by_name['resources'].message_type = _GETRESOURCESREPLY_RESOURCESENTRY
_UPDATERESOURCESREQUEST_RESOURCESENTRY.fields_by_name['value'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCETABLEDATA
_UPDATERESOURCESREQUEST_RESOURCESENTRY.containing_type = _UPDATERESOURCESREQUEST
_UPDATERESOURCESREQUEST.fields_by_name['resources'].message_type = _UPDATERESOURCESREQUEST_RESOURCESENTRY
_UPDATERESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_DELETERESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLAVAILABLERESOURCESREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLAVAILABLERESOURCESREPLY.fields_by_name['resources_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._AVAILABLERESOURCES
_REPORTRESOURCEUSAGEREQUEST.fields_by_name['resources'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCESDATA
_REPORTRESOURCEUSAGEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETOBJECTLOCATIONSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETOBJECTLOCATIONSREPLY.fields_by_name['location_info'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._OBJECTLOCATIONINFO
_GETALLOBJECTLOCATIONSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLOBJECTLOCATIONSREPLY.fields_by_name['object_location_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._OBJECTLOCATIONINFO
_ADDOBJECTLOCATIONREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_ADDOBJECTSPILLEDURLREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REMOVEOBJECTLOCATIONREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_ADDTASKREQUEST.fields_by_name['task_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKTABLEDATA
_ADDTASKREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKREPLY.fields_by_name['task_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKTABLEDATA
_ADDTASKLEASEREQUEST.fields_by_name['task_lease_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKLEASEDATA
_ADDTASKLEASEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKLEASEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETTASKLEASEREPLY.fields_by_name['task_lease_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKLEASEDATA
_ATTEMPTTASKRECONSTRUCTIONREQUEST.fields_by_name['task_reconstruction'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._TASKRECONSTRUCTIONDATA
_ATTEMPTTASKRECONSTRUCTIONREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_ADDPROFILEDATAREQUEST.fields_by_name['profile_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PROFILETABLEDATA
_ADDPROFILEDATAREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLPROFILEINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLPROFILEINFOREPLY.fields_by_name['profile_info_list'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PROFILETABLEDATA
_REPORTWORKERFAILUREREQUEST.fields_by_name['worker_failure'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_REPORTWORKERFAILUREREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETWORKERINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETWORKERINFOREPLY.fields_by_name['worker_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_GETALLWORKERINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLWORKERINFOREPLY.fields_by_name['worker_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_ADDWORKERINFOREQUEST.fields_by_name['worker_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._WORKERTABLEDATA
_ADDWORKERINFOREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_CREATEACTORREQUEST.fields_by_name['task_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASKSPEC
_CREATEACTORREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REGISTERACTORREQUEST.fields_by_name['task_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._TASKSPEC
_REGISTERACTORREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['placement_group_spec'].message_type = src_dot_ray_dot_protobuf_dot_common__pb2._PLACEMENTGROUPSPEC
_CREATEPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_REMOVEPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETPLACEMENTGROUPREPLY.fields_by_name['placement_group_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PLACEMENTGROUPTABLEDATA
_GETALLPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLPLACEMENTGROUPREPLY.fields_by_name['placement_group_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PLACEMENTGROUPTABLEDATA
_WAITPLACEMENTGROUPUNTILREADYREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETNAMEDPLACEMENTGROUPREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETNAMEDPLACEMENTGROUPREPLY.fields_by_name['placement_group_table_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._PLACEMENTGROUPTABLEDATA
_INTERNALKVGETREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_INTERNALKVPUTREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_INTERNALKVDELREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_INTERNALKVEXISTSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_INTERNALKVKEYSREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLRESOURCEUSAGEREPLY.fields_by_name['status'].message_type = _GCSSTATUS
_GETALLRESOURCEUSAGEREPLY.fields_by_name['resource_usage_data'].message_type = src_dot_ray_dot_protobuf_dot_gcs__pb2._RESOURCEUSAGEBATCHDATA
DESCRIPTOR.message_types_by_name['AddJobRequest'] = _ADDJOBREQUEST
DESCRIPTOR.message_types_by_name['AddJobReply'] = _ADDJOBREPLY
DESCRIPTOR.message_types_by_name['MarkJobFinishedRequest'] = _MARKJOBFINISHEDREQUEST
DESCRIPTOR.message_types_by_name['MarkJobFinishedReply'] = _MARKJOBFINISHEDREPLY
DESCRIPTOR.message_types_by_name['GetAllJobInfoRequest'] = _GETALLJOBINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllJobInfoReply'] = _GETALLJOBINFOREPLY
DESCRIPTOR.message_types_by_name['ReportJobErrorRequest'] = _REPORTJOBERRORREQUEST
DESCRIPTOR.message_types_by_name['ReportJobErrorReply'] = _REPORTJOBERRORREPLY
DESCRIPTOR.message_types_by_name['GetNextJobIDRequest'] = _GETNEXTJOBIDREQUEST
DESCRIPTOR.message_types_by_name['GetNextJobIDReply'] = _GETNEXTJOBIDREPLY
DESCRIPTOR.message_types_by_name['GetActorInfoRequest'] = _GETACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['GetActorInfoReply'] = _GETACTORINFOREPLY
DESCRIPTOR.message_types_by_name['GetNamedActorInfoRequest'] = _GETNAMEDACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['GetNamedActorInfoReply'] = _GETNAMEDACTORINFOREPLY
DESCRIPTOR.message_types_by_name['ListNamedActorsRequest'] = _LISTNAMEDACTORSREQUEST
DESCRIPTOR.message_types_by_name['ListNamedActorsReply'] = _LISTNAMEDACTORSREPLY
DESCRIPTOR.message_types_by_name['GetAllActorInfoRequest'] = _GETALLACTORINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllActorInfoReply'] = _GETALLACTORINFOREPLY
DESCRIPTOR.message_types_by_name['KillActorViaGcsRequest'] = _KILLACTORVIAGCSREQUEST
DESCRIPTOR.message_types_by_name['KillActorViaGcsReply'] = _KILLACTORVIAGCSREPLY
DESCRIPTOR.message_types_by_name['RegisterNodeRequest'] = _REGISTERNODEREQUEST
DESCRIPTOR.message_types_by_name['RegisterNodeReply'] = _REGISTERNODEREPLY
DESCRIPTOR.message_types_by_name['UnregisterNodeRequest'] = _UNREGISTERNODEREQUEST
DESCRIPTOR.message_types_by_name['UnregisterNodeReply'] = _UNREGISTERNODEREPLY
DESCRIPTOR.message_types_by_name['GetAllNodeInfoRequest'] = _GETALLNODEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllNodeInfoReply'] = _GETALLNODEINFOREPLY
DESCRIPTOR.message_types_by_name['ReportHeartbeatRequest'] = _REPORTHEARTBEATREQUEST
DESCRIPTOR.message_types_by_name['ReportHeartbeatReply'] = _REPORTHEARTBEATREPLY
DESCRIPTOR.message_types_by_name['CheckAliveRequest'] = _CHECKALIVEREQUEST
DESCRIPTOR.message_types_by_name['CheckAliveReply'] = _CHECKALIVEREPLY
DESCRIPTOR.message_types_by_name['GetInternalConfigRequest'] = _GETINTERNALCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetInternalConfigReply'] = _GETINTERNALCONFIGREPLY
DESCRIPTOR.message_types_by_name['GetResourcesRequest'] = _GETRESOURCESREQUEST
DESCRIPTOR.message_types_by_name['GetResourcesReply'] = _GETRESOURCESREPLY
DESCRIPTOR.message_types_by_name['UpdateResourcesRequest'] = _UPDATERESOURCESREQUEST
DESCRIPTOR.message_types_by_name['UpdateResourcesReply'] = _UPDATERESOURCESREPLY
DESCRIPTOR.message_types_by_name['DeleteResourcesRequest'] = _DELETERESOURCESREQUEST
DESCRIPTOR.message_types_by_name['DeleteResourcesReply'] = _DELETERESOURCESREPLY
DESCRIPTOR.message_types_by_name['GetAllAvailableResourcesRequest'] = _GETALLAVAILABLERESOURCESREQUEST
DESCRIPTOR.message_types_by_name['GetAllAvailableResourcesReply'] = _GETALLAVAILABLERESOURCESREPLY
DESCRIPTOR.message_types_by_name['ReportResourceUsageRequest'] = _REPORTRESOURCEUSAGEREQUEST
DESCRIPTOR.message_types_by_name['ReportResourceUsageReply'] = _REPORTRESOURCEUSAGEREPLY
DESCRIPTOR.message_types_by_name['GetObjectLocationsRequest'] = _GETOBJECTLOCATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetObjectLocationsReply'] = _GETOBJECTLOCATIONSREPLY
DESCRIPTOR.message_types_by_name['GetAllObjectLocationsRequest'] = _GETALLOBJECTLOCATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetAllObjectLocationsReply'] = _GETALLOBJECTLOCATIONSREPLY
DESCRIPTOR.message_types_by_name['AddObjectLocationRequest'] = _ADDOBJECTLOCATIONREQUEST
DESCRIPTOR.message_types_by_name['AddObjectLocationReply'] = _ADDOBJECTLOCATIONREPLY
DESCRIPTOR.message_types_by_name['AddObjectSpilledUrlReply'] = _ADDOBJECTSPILLEDURLREPLY
DESCRIPTOR.message_types_by_name['RemoveObjectLocationRequest'] = _REMOVEOBJECTLOCATIONREQUEST
DESCRIPTOR.message_types_by_name['RemoveObjectLocationReply'] = _REMOVEOBJECTLOCATIONREPLY
DESCRIPTOR.message_types_by_name['AddTaskRequest'] = _ADDTASKREQUEST
DESCRIPTOR.message_types_by_name['AddTaskReply'] = _ADDTASKREPLY
DESCRIPTOR.message_types_by_name['GetTaskRequest'] = _GETTASKREQUEST
DESCRIPTOR.message_types_by_name['GetTaskReply'] = _GETTASKREPLY
DESCRIPTOR.message_types_by_name['AddTaskLeaseRequest'] = _ADDTASKLEASEREQUEST
DESCRIPTOR.message_types_by_name['AddTaskLeaseReply'] = _ADDTASKLEASEREPLY
DESCRIPTOR.message_types_by_name['GetTaskLeaseRequest'] = _GETTASKLEASEREQUEST
DESCRIPTOR.message_types_by_name['GetTaskLeaseReply'] = _GETTASKLEASEREPLY
DESCRIPTOR.message_types_by_name['AttemptTaskReconstructionRequest'] = _ATTEMPTTASKRECONSTRUCTIONREQUEST
DESCRIPTOR.message_types_by_name['AttemptTaskReconstructionReply'] = _ATTEMPTTASKRECONSTRUCTIONREPLY
DESCRIPTOR.message_types_by_name['AddProfileDataRequest'] = _ADDPROFILEDATAREQUEST
DESCRIPTOR.message_types_by_name['AddProfileDataReply'] = _ADDPROFILEDATAREPLY
DESCRIPTOR.message_types_by_name['GetAllProfileInfoRequest'] = _GETALLPROFILEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllProfileInfoReply'] = _GETALLPROFILEINFOREPLY
DESCRIPTOR.message_types_by_name['ReportWorkerFailureRequest'] = _REPORTWORKERFAILUREREQUEST
DESCRIPTOR.message_types_by_name['ReportWorkerFailureReply'] = _REPORTWORKERFAILUREREPLY
DESCRIPTOR.message_types_by_name['GetWorkerInfoRequest'] = _GETWORKERINFOREQUEST
DESCRIPTOR.message_types_by_name['GetWorkerInfoReply'] = _GETWORKERINFOREPLY
DESCRIPTOR.message_types_by_name['GetAllWorkerInfoRequest'] = _GETALLWORKERINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAllWorkerInfoReply'] = _GETALLWORKERINFOREPLY
DESCRIPTOR.message_types_by_name['AddWorkerInfoRequest'] = _ADDWORKERINFOREQUEST
DESCRIPTOR.message_types_by_name['AddWorkerInfoReply'] = _ADDWORKERINFOREPLY
DESCRIPTOR.message_types_by_name['CreateActorRequest'] = _CREATEACTORREQUEST
DESCRIPTOR.message_types_by_name['CreateActorReply'] = _CREATEACTORREPLY
DESCRIPTOR.message_types_by_name['RegisterActorRequest'] = _REGISTERACTORREQUEST
DESCRIPTOR.message_types_by_name['RegisterActorReply'] = _REGISTERACTORREPLY
DESCRIPTOR.message_types_by_name['CreatePlacementGroupRequest'] = _CREATEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreatePlacementGroupReply'] = _CREATEPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['RemovePlacementGroupRequest'] = _REMOVEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['RemovePlacementGroupReply'] = _REMOVEPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['GetPlacementGroupRequest'] = _GETPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetPlacementGroupReply'] = _GETPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['GetAllPlacementGroupRequest'] = _GETALLPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetAllPlacementGroupReply'] = _GETALLPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['WaitPlacementGroupUntilReadyRequest'] = _WAITPLACEMENTGROUPUNTILREADYREQUEST
DESCRIPTOR.message_types_by_name['WaitPlacementGroupUntilReadyReply'] = _WAITPLACEMENTGROUPUNTILREADYREPLY
DESCRIPTOR.message_types_by_name['GetNamedPlacementGroupRequest'] = _GETNAMEDPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetNamedPlacementGroupReply'] = _GETNAMEDPLACEMENTGROUPREPLY
DESCRIPTOR.message_types_by_name['InternalKVGetRequest'] = _INTERNALKVGETREQUEST
DESCRIPTOR.message_types_by_name['InternalKVGetReply'] = _INTERNALKVGETREPLY
DESCRIPTOR.message_types_by_name['InternalKVPutRequest'] = _INTERNALKVPUTREQUEST
DESCRIPTOR.message_types_by_name['InternalKVPutReply'] = _INTERNALKVPUTREPLY
DESCRIPTOR.message_types_by_name['InternalKVDelRequest'] = _INTERNALKVDELREQUEST
DESCRIPTOR.message_types_by_name['InternalKVDelReply'] = _INTERNALKVDELREPLY
DESCRIPTOR.message_types_by_name['InternalKVExistsRequest'] = _INTERNALKVEXISTSREQUEST
DESCRIPTOR.message_types_by_name['InternalKVExistsReply'] = _INTERNALKVEXISTSREPLY
DESCRIPTOR.message_types_by_name['InternalKVKeysRequest'] = _INTERNALKVKEYSREQUEST
DESCRIPTOR.message_types_by_name['InternalKVKeysReply'] = _INTERNALKVKEYSREPLY
DESCRIPTOR.message_types_by_name['GetAllResourceUsageRequest'] = _GETALLRESOURCEUSAGEREQUEST
DESCRIPTOR.message_types_by_name['GetAllResourceUsageReply'] = _GETALLRESOURCEUSAGEREPLY
DESCRIPTOR.message_types_by_name['GcsStatus'] = _GCSSTATUS
DESCRIPTOR.enum_types_by_name['GcsServiceFailureType'] = _GCSSERVICEFAILURETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AddJobRequest = _reflection.GeneratedProtocolMessageType('AddJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDJOBREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddJobRequest)
  })
_sym_db.RegisterMessage(AddJobRequest)

AddJobReply = _reflection.GeneratedProtocolMessageType('AddJobReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDJOBREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddJobReply)
  })
_sym_db.RegisterMessage(AddJobReply)

MarkJobFinishedRequest = _reflection.GeneratedProtocolMessageType('MarkJobFinishedRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKJOBFINISHEDREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MarkJobFinishedRequest)
  })
_sym_db.RegisterMessage(MarkJobFinishedRequest)

MarkJobFinishedReply = _reflection.GeneratedProtocolMessageType('MarkJobFinishedReply', (_message.Message,), {
  'DESCRIPTOR' : _MARKJOBFINISHEDREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MarkJobFinishedReply)
  })
_sym_db.RegisterMessage(MarkJobFinishedReply)

GetAllJobInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllJobInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLJOBINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllJobInfoRequest)
  })
_sym_db.RegisterMessage(GetAllJobInfoRequest)

GetAllJobInfoReply = _reflection.GeneratedProtocolMessageType('GetAllJobInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLJOBINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllJobInfoReply)
  })
_sym_db.RegisterMessage(GetAllJobInfoReply)

ReportJobErrorRequest = _reflection.GeneratedProtocolMessageType('ReportJobErrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTJOBERRORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportJobErrorRequest)
  })
_sym_db.RegisterMessage(ReportJobErrorRequest)

ReportJobErrorReply = _reflection.GeneratedProtocolMessageType('ReportJobErrorReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTJOBERRORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportJobErrorReply)
  })
_sym_db.RegisterMessage(ReportJobErrorReply)

GetNextJobIDRequest = _reflection.GeneratedProtocolMessageType('GetNextJobIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTJOBIDREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNextJobIDRequest)
  })
_sym_db.RegisterMessage(GetNextJobIDRequest)

GetNextJobIDReply = _reflection.GeneratedProtocolMessageType('GetNextJobIDReply', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTJOBIDREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNextJobIDReply)
  })
_sym_db.RegisterMessage(GetNextJobIDReply)

GetActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetActorInfoRequest)
  })
_sym_db.RegisterMessage(GetActorInfoRequest)

GetActorInfoReply = _reflection.GeneratedProtocolMessageType('GetActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetActorInfoReply)
  })
_sym_db.RegisterMessage(GetActorInfoReply)

GetNamedActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetNamedActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedActorInfoRequest)
  })
_sym_db.RegisterMessage(GetNamedActorInfoRequest)

GetNamedActorInfoReply = _reflection.GeneratedProtocolMessageType('GetNamedActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedActorInfoReply)
  })
_sym_db.RegisterMessage(GetNamedActorInfoReply)

ListNamedActorsRequest = _reflection.GeneratedProtocolMessageType('ListNamedActorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNAMEDACTORSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ListNamedActorsRequest)
  })
_sym_db.RegisterMessage(ListNamedActorsRequest)

ListNamedActorsReply = _reflection.GeneratedProtocolMessageType('ListNamedActorsReply', (_message.Message,), {
  'DESCRIPTOR' : _LISTNAMEDACTORSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ListNamedActorsReply)
  })
_sym_db.RegisterMessage(ListNamedActorsReply)

GetAllActorInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllActorInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLACTORINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllActorInfoRequest)
  })
_sym_db.RegisterMessage(GetAllActorInfoRequest)

GetAllActorInfoReply = _reflection.GeneratedProtocolMessageType('GetAllActorInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLACTORINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllActorInfoReply)
  })
_sym_db.RegisterMessage(GetAllActorInfoReply)

KillActorViaGcsRequest = _reflection.GeneratedProtocolMessageType('KillActorViaGcsRequest', (_message.Message,), {
  'DESCRIPTOR' : _KILLACTORVIAGCSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KillActorViaGcsRequest)
  })
_sym_db.RegisterMessage(KillActorViaGcsRequest)

KillActorViaGcsReply = _reflection.GeneratedProtocolMessageType('KillActorViaGcsReply', (_message.Message,), {
  'DESCRIPTOR' : _KILLACTORVIAGCSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.KillActorViaGcsReply)
  })
_sym_db.RegisterMessage(KillActorViaGcsReply)

RegisterNodeRequest = _reflection.GeneratedProtocolMessageType('RegisterNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERNODEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterNodeRequest)
  })
_sym_db.RegisterMessage(RegisterNodeRequest)

RegisterNodeReply = _reflection.GeneratedProtocolMessageType('RegisterNodeReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERNODEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterNodeReply)
  })
_sym_db.RegisterMessage(RegisterNodeReply)

UnregisterNodeRequest = _reflection.GeneratedProtocolMessageType('UnregisterNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTERNODEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UnregisterNodeRequest)
  })
_sym_db.RegisterMessage(UnregisterNodeRequest)

UnregisterNodeReply = _reflection.GeneratedProtocolMessageType('UnregisterNodeReply', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTERNODEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UnregisterNodeReply)
  })
_sym_db.RegisterMessage(UnregisterNodeReply)

GetAllNodeInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllNodeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLNODEINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllNodeInfoRequest)
  })
_sym_db.RegisterMessage(GetAllNodeInfoRequest)

GetAllNodeInfoReply = _reflection.GeneratedProtocolMessageType('GetAllNodeInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLNODEINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllNodeInfoReply)
  })
_sym_db.RegisterMessage(GetAllNodeInfoReply)

ReportHeartbeatRequest = _reflection.GeneratedProtocolMessageType('ReportHeartbeatRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTHEARTBEATREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportHeartbeatRequest)
  })
_sym_db.RegisterMessage(ReportHeartbeatRequest)

ReportHeartbeatReply = _reflection.GeneratedProtocolMessageType('ReportHeartbeatReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTHEARTBEATREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportHeartbeatReply)
  })
_sym_db.RegisterMessage(ReportHeartbeatReply)

CheckAliveRequest = _reflection.GeneratedProtocolMessageType('CheckAliveRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKALIVEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CheckAliveRequest)
  })
_sym_db.RegisterMessage(CheckAliveRequest)

CheckAliveReply = _reflection.GeneratedProtocolMessageType('CheckAliveReply', (_message.Message,), {
  'DESCRIPTOR' : _CHECKALIVEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CheckAliveReply)
  })
_sym_db.RegisterMessage(CheckAliveReply)

GetInternalConfigRequest = _reflection.GeneratedProtocolMessageType('GetInternalConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERNALCONFIGREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetInternalConfigRequest)
  })
_sym_db.RegisterMessage(GetInternalConfigRequest)

GetInternalConfigReply = _reflection.GeneratedProtocolMessageType('GetInternalConfigReply', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERNALCONFIGREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetInternalConfigReply)
  })
_sym_db.RegisterMessage(GetInternalConfigReply)

GetResourcesRequest = _reflection.GeneratedProtocolMessageType('GetResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesRequest)
  })
_sym_db.RegisterMessage(GetResourcesRequest)

GetResourcesReply = _reflection.GeneratedProtocolMessageType('GetResourcesReply', (_message.Message,), {

  'ResourcesEntry' : _reflection.GeneratedProtocolMessageType('ResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETRESOURCESREPLY_RESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.gcs_service_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesReply.ResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _GETRESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetResourcesReply)
  })
_sym_db.RegisterMessage(GetResourcesReply)
_sym_db.RegisterMessage(GetResourcesReply.ResourcesEntry)

UpdateResourcesRequest = _reflection.GeneratedProtocolMessageType('UpdateResourcesRequest', (_message.Message,), {

  'ResourcesEntry' : _reflection.GeneratedProtocolMessageType('ResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATERESOURCESREQUEST_RESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.gcs_service_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.UpdateResourcesRequest.ResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATERESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UpdateResourcesRequest)
  })
_sym_db.RegisterMessage(UpdateResourcesRequest)
_sym_db.RegisterMessage(UpdateResourcesRequest.ResourcesEntry)

UpdateResourcesReply = _reflection.GeneratedProtocolMessageType('UpdateResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.UpdateResourcesReply)
  })
_sym_db.RegisterMessage(UpdateResourcesReply)

DeleteResourcesRequest = _reflection.GeneratedProtocolMessageType('DeleteResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DeleteResourcesRequest)
  })
_sym_db.RegisterMessage(DeleteResourcesRequest)

DeleteResourcesReply = _reflection.GeneratedProtocolMessageType('DeleteResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _DELETERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.DeleteResourcesReply)
  })
_sym_db.RegisterMessage(DeleteResourcesReply)

GetAllAvailableResourcesRequest = _reflection.GeneratedProtocolMessageType('GetAllAvailableResourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLAVAILABLERESOURCESREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllAvailableResourcesRequest)
  })
_sym_db.RegisterMessage(GetAllAvailableResourcesRequest)

GetAllAvailableResourcesReply = _reflection.GeneratedProtocolMessageType('GetAllAvailableResourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLAVAILABLERESOURCESREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllAvailableResourcesReply)
  })
_sym_db.RegisterMessage(GetAllAvailableResourcesReply)

ReportResourceUsageRequest = _reflection.GeneratedProtocolMessageType('ReportResourceUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTRESOURCEUSAGEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportResourceUsageRequest)
  })
_sym_db.RegisterMessage(ReportResourceUsageRequest)

ReportResourceUsageReply = _reflection.GeneratedProtocolMessageType('ReportResourceUsageReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTRESOURCEUSAGEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportResourceUsageReply)
  })
_sym_db.RegisterMessage(ReportResourceUsageReply)

GetObjectLocationsRequest = _reflection.GeneratedProtocolMessageType('GetObjectLocationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTLOCATIONSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetObjectLocationsRequest)
  })
_sym_db.RegisterMessage(GetObjectLocationsRequest)

GetObjectLocationsReply = _reflection.GeneratedProtocolMessageType('GetObjectLocationsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTLOCATIONSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetObjectLocationsReply)
  })
_sym_db.RegisterMessage(GetObjectLocationsReply)

GetAllObjectLocationsRequest = _reflection.GeneratedProtocolMessageType('GetAllObjectLocationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLOBJECTLOCATIONSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllObjectLocationsRequest)
  })
_sym_db.RegisterMessage(GetAllObjectLocationsRequest)

GetAllObjectLocationsReply = _reflection.GeneratedProtocolMessageType('GetAllObjectLocationsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLOBJECTLOCATIONSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllObjectLocationsReply)
  })
_sym_db.RegisterMessage(GetAllObjectLocationsReply)

AddObjectLocationRequest = _reflection.GeneratedProtocolMessageType('AddObjectLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDOBJECTLOCATIONREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddObjectLocationRequest)
  })
_sym_db.RegisterMessage(AddObjectLocationRequest)

AddObjectLocationReply = _reflection.GeneratedProtocolMessageType('AddObjectLocationReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDOBJECTLOCATIONREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddObjectLocationReply)
  })
_sym_db.RegisterMessage(AddObjectLocationReply)

AddObjectSpilledUrlReply = _reflection.GeneratedProtocolMessageType('AddObjectSpilledUrlReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDOBJECTSPILLEDURLREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddObjectSpilledUrlReply)
  })
_sym_db.RegisterMessage(AddObjectSpilledUrlReply)

RemoveObjectLocationRequest = _reflection.GeneratedProtocolMessageType('RemoveObjectLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOBJECTLOCATIONREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemoveObjectLocationRequest)
  })
_sym_db.RegisterMessage(RemoveObjectLocationRequest)

RemoveObjectLocationReply = _reflection.GeneratedProtocolMessageType('RemoveObjectLocationReply', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOBJECTLOCATIONREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemoveObjectLocationReply)
  })
_sym_db.RegisterMessage(RemoveObjectLocationReply)

AddTaskRequest = _reflection.GeneratedProtocolMessageType('AddTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskRequest)
  })
_sym_db.RegisterMessage(AddTaskRequest)

AddTaskReply = _reflection.GeneratedProtocolMessageType('AddTaskReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskReply)
  })
_sym_db.RegisterMessage(AddTaskReply)

GetTaskRequest = _reflection.GeneratedProtocolMessageType('GetTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskRequest)
  })
_sym_db.RegisterMessage(GetTaskRequest)

GetTaskReply = _reflection.GeneratedProtocolMessageType('GetTaskReply', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskReply)
  })
_sym_db.RegisterMessage(GetTaskReply)

AddTaskLeaseRequest = _reflection.GeneratedProtocolMessageType('AddTaskLeaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKLEASEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskLeaseRequest)
  })
_sym_db.RegisterMessage(AddTaskLeaseRequest)

AddTaskLeaseReply = _reflection.GeneratedProtocolMessageType('AddTaskLeaseReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDTASKLEASEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddTaskLeaseReply)
  })
_sym_db.RegisterMessage(AddTaskLeaseReply)

GetTaskLeaseRequest = _reflection.GeneratedProtocolMessageType('GetTaskLeaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKLEASEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskLeaseRequest)
  })
_sym_db.RegisterMessage(GetTaskLeaseRequest)

GetTaskLeaseReply = _reflection.GeneratedProtocolMessageType('GetTaskLeaseReply', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKLEASEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetTaskLeaseReply)
  })
_sym_db.RegisterMessage(GetTaskLeaseReply)

AttemptTaskReconstructionRequest = _reflection.GeneratedProtocolMessageType('AttemptTaskReconstructionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTEMPTTASKRECONSTRUCTIONREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AttemptTaskReconstructionRequest)
  })
_sym_db.RegisterMessage(AttemptTaskReconstructionRequest)

AttemptTaskReconstructionReply = _reflection.GeneratedProtocolMessageType('AttemptTaskReconstructionReply', (_message.Message,), {
  'DESCRIPTOR' : _ATTEMPTTASKRECONSTRUCTIONREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AttemptTaskReconstructionReply)
  })
_sym_db.RegisterMessage(AttemptTaskReconstructionReply)

AddProfileDataRequest = _reflection.GeneratedProtocolMessageType('AddProfileDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPROFILEDATAREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddProfileDataRequest)
  })
_sym_db.RegisterMessage(AddProfileDataRequest)

AddProfileDataReply = _reflection.GeneratedProtocolMessageType('AddProfileDataReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDPROFILEDATAREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddProfileDataReply)
  })
_sym_db.RegisterMessage(AddProfileDataReply)

GetAllProfileInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllProfileInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPROFILEINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllProfileInfoRequest)
  })
_sym_db.RegisterMessage(GetAllProfileInfoRequest)

GetAllProfileInfoReply = _reflection.GeneratedProtocolMessageType('GetAllProfileInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPROFILEINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllProfileInfoReply)
  })
_sym_db.RegisterMessage(GetAllProfileInfoReply)

ReportWorkerFailureRequest = _reflection.GeneratedProtocolMessageType('ReportWorkerFailureRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTWORKERFAILUREREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportWorkerFailureRequest)
  })
_sym_db.RegisterMessage(ReportWorkerFailureRequest)

ReportWorkerFailureReply = _reflection.GeneratedProtocolMessageType('ReportWorkerFailureReply', (_message.Message,), {
  'DESCRIPTOR' : _REPORTWORKERFAILUREREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ReportWorkerFailureReply)
  })
_sym_db.RegisterMessage(ReportWorkerFailureReply)

GetWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('GetWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetWorkerInfoRequest)
  })
_sym_db.RegisterMessage(GetWorkerInfoRequest)

GetWorkerInfoReply = _reflection.GeneratedProtocolMessageType('GetWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetWorkerInfoReply)
  })
_sym_db.RegisterMessage(GetWorkerInfoReply)

GetAllWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllWorkerInfoRequest)
  })
_sym_db.RegisterMessage(GetAllWorkerInfoRequest)

GetAllWorkerInfoReply = _reflection.GeneratedProtocolMessageType('GetAllWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllWorkerInfoReply)
  })
_sym_db.RegisterMessage(GetAllWorkerInfoReply)

AddWorkerInfoRequest = _reflection.GeneratedProtocolMessageType('AddWorkerInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDWORKERINFOREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddWorkerInfoRequest)
  })
_sym_db.RegisterMessage(AddWorkerInfoRequest)

AddWorkerInfoReply = _reflection.GeneratedProtocolMessageType('AddWorkerInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDWORKERINFOREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.AddWorkerInfoReply)
  })
_sym_db.RegisterMessage(AddWorkerInfoReply)

CreateActorRequest = _reflection.GeneratedProtocolMessageType('CreateActorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACTORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreateActorRequest)
  })
_sym_db.RegisterMessage(CreateActorRequest)

CreateActorReply = _reflection.GeneratedProtocolMessageType('CreateActorReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACTORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreateActorReply)
  })
_sym_db.RegisterMessage(CreateActorReply)

RegisterActorRequest = _reflection.GeneratedProtocolMessageType('RegisterActorRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorRequest)
  })
_sym_db.RegisterMessage(RegisterActorRequest)

RegisterActorReply = _reflection.GeneratedProtocolMessageType('RegisterActorReply', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERACTORREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RegisterActorReply)
  })
_sym_db.RegisterMessage(RegisterActorReply)

CreatePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreatePlacementGroupRequest)
  })
_sym_db.RegisterMessage(CreatePlacementGroupRequest)

CreatePlacementGroupReply = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CreatePlacementGroupReply)
  })
_sym_db.RegisterMessage(CreatePlacementGroupReply)

RemovePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('RemovePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemovePlacementGroupRequest)
  })
_sym_db.RegisterMessage(RemovePlacementGroupRequest)

RemovePlacementGroupReply = _reflection.GeneratedProtocolMessageType('RemovePlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RemovePlacementGroupReply)
  })
_sym_db.RegisterMessage(RemovePlacementGroupReply)

GetPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetPlacementGroupRequest)

GetPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetPlacementGroupReply)

GetAllPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetAllPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetAllPlacementGroupRequest)

GetAllPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetAllPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetAllPlacementGroupReply)

WaitPlacementGroupUntilReadyRequest = _reflection.GeneratedProtocolMessageType('WaitPlacementGroupUntilReadyRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITPLACEMENTGROUPUNTILREADYREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitPlacementGroupUntilReadyRequest)
  })
_sym_db.RegisterMessage(WaitPlacementGroupUntilReadyRequest)

WaitPlacementGroupUntilReadyReply = _reflection.GeneratedProtocolMessageType('WaitPlacementGroupUntilReadyReply', (_message.Message,), {
  'DESCRIPTOR' : _WAITPLACEMENTGROUPUNTILREADYREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.WaitPlacementGroupUntilReadyReply)
  })
_sym_db.RegisterMessage(WaitPlacementGroupUntilReadyReply)

GetNamedPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetNamedPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDPLACEMENTGROUPREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetNamedPlacementGroupRequest)

GetNamedPlacementGroupReply = _reflection.GeneratedProtocolMessageType('GetNamedPlacementGroupReply', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMEDPLACEMENTGROUPREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetNamedPlacementGroupReply)
  })
_sym_db.RegisterMessage(GetNamedPlacementGroupReply)

InternalKVGetRequest = _reflection.GeneratedProtocolMessageType('InternalKVGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVGETREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVGetRequest)
  })
_sym_db.RegisterMessage(InternalKVGetRequest)

InternalKVGetReply = _reflection.GeneratedProtocolMessageType('InternalKVGetReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVGETREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVGetReply)
  })
_sym_db.RegisterMessage(InternalKVGetReply)

InternalKVPutRequest = _reflection.GeneratedProtocolMessageType('InternalKVPutRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVPUTREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVPutRequest)
  })
_sym_db.RegisterMessage(InternalKVPutRequest)

InternalKVPutReply = _reflection.GeneratedProtocolMessageType('InternalKVPutReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVPUTREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVPutReply)
  })
_sym_db.RegisterMessage(InternalKVPutReply)

InternalKVDelRequest = _reflection.GeneratedProtocolMessageType('InternalKVDelRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVDELREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVDelRequest)
  })
_sym_db.RegisterMessage(InternalKVDelRequest)

InternalKVDelReply = _reflection.GeneratedProtocolMessageType('InternalKVDelReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVDELREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVDelReply)
  })
_sym_db.RegisterMessage(InternalKVDelReply)

InternalKVExistsRequest = _reflection.GeneratedProtocolMessageType('InternalKVExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVEXISTSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVExistsRequest)
  })
_sym_db.RegisterMessage(InternalKVExistsRequest)

InternalKVExistsReply = _reflection.GeneratedProtocolMessageType('InternalKVExistsReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVEXISTSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVExistsReply)
  })
_sym_db.RegisterMessage(InternalKVExistsReply)

InternalKVKeysRequest = _reflection.GeneratedProtocolMessageType('InternalKVKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVKEYSREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVKeysRequest)
  })
_sym_db.RegisterMessage(InternalKVKeysRequest)

InternalKVKeysReply = _reflection.GeneratedProtocolMessageType('InternalKVKeysReply', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALKVKEYSREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.InternalKVKeysReply)
  })
_sym_db.RegisterMessage(InternalKVKeysReply)

GetAllResourceUsageRequest = _reflection.GeneratedProtocolMessageType('GetAllResourceUsageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLRESOURCEUSAGEREQUEST,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllResourceUsageRequest)
  })
_sym_db.RegisterMessage(GetAllResourceUsageRequest)

GetAllResourceUsageReply = _reflection.GeneratedProtocolMessageType('GetAllResourceUsageReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLRESOURCEUSAGEREPLY,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GetAllResourceUsageReply)
  })
_sym_db.RegisterMessage(GetAllResourceUsageReply)

GcsStatus = _reflection.GeneratedProtocolMessageType('GcsStatus', (_message.Message,), {
  'DESCRIPTOR' : _GCSSTATUS,
  '__module__' : 'src.ray.protobuf.gcs_service_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.GcsStatus)
  })
_sym_db.RegisterMessage(GcsStatus)


_GETRESOURCESREPLY_RESOURCESENTRY._options = None
_UPDATERESOURCESREQUEST_RESOURCESENTRY._options = None

_JOBINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='JobInfoGcsService',
  full_name='ray.rpc.JobInfoGcsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=8868,
  serialized_end=9257,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddJob',
    full_name='ray.rpc.JobInfoGcsService.AddJob',
    index=0,
    containing_service=None,
    input_type=_ADDJOBREQUEST,
    output_type=_ADDJOBREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MarkJobFinished',
    full_name='ray.rpc.JobInfoGcsService.MarkJobFinished',
    index=1,
    containing_service=None,
    input_type=_MARKJOBFINISHEDREQUEST,
    output_type=_MARKJOBFINISHEDREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllJobInfo',
    full_name='ray.rpc.JobInfoGcsService.GetAllJobInfo',
    index=2,
    containing_service=None,
    input_type=_GETALLJOBINFOREQUEST,
    output_type=_GETALLJOBINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportJobError',
    full_name='ray.rpc.JobInfoGcsService.ReportJobError',
    index=3,
    containing_service=None,
    input_type=_REPORTJOBERRORREQUEST,
    output_type=_REPORTJOBERRORREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNextJobID',
    full_name='ray.rpc.JobInfoGcsService.GetNextJobID',
    index=4,
    containing_service=None,
    input_type=_GETNEXTJOBIDREQUEST,
    output_type=_GETNEXTJOBIDREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBINFOGCSSERVICE)

DESCRIPTOR.services_by_name['JobInfoGcsService'] = _JOBINFOGCSSERVICE


_ACTORINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='ActorInfoGcsService',
  full_name='ray.rpc.ActorInfoGcsService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=9260,
  serialized_end=9841,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterActor',
    full_name='ray.rpc.ActorInfoGcsService.RegisterActor',
    index=0,
    containing_service=None,
    input_type=_REGISTERACTORREQUEST,
    output_type=_REGISTERACTORREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateActor',
    full_name='ray.rpc.ActorInfoGcsService.CreateActor',
    index=1,
    containing_service=None,
    input_type=_CREATEACTORREQUEST,
    output_type=_CREATEACTORREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.GetActorInfo',
    index=2,
    containing_service=None,
    input_type=_GETACTORINFOREQUEST,
    output_type=_GETACTORINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNamedActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.GetNamedActorInfo',
    index=3,
    containing_service=None,
    input_type=_GETNAMEDACTORINFOREQUEST,
    output_type=_GETNAMEDACTORINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNamedActors',
    full_name='ray.rpc.ActorInfoGcsService.ListNamedActors',
    index=4,
    containing_service=None,
    input_type=_LISTNAMEDACTORSREQUEST,
    output_type=_LISTNAMEDACTORSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllActorInfo',
    full_name='ray.rpc.ActorInfoGcsService.GetAllActorInfo',
    index=5,
    containing_service=None,
    input_type=_GETALLACTORINFOREQUEST,
    output_type=_GETALLACTORINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KillActorViaGcs',
    full_name='ray.rpc.ActorInfoGcsService.KillActorViaGcs',
    index=6,
    containing_service=None,
    input_type=_KILLACTORVIAGCSREQUEST,
    output_type=_KILLACTORVIAGCSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACTORINFOGCSSERVICE)

DESCRIPTOR.services_by_name['ActorInfoGcsService'] = _ACTORINFOGCSSERVICE


_NODEINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='NodeInfoGcsService',
  full_name='ray.rpc.NodeInfoGcsService',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=9844,
  serialized_end=10187,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterNode',
    full_name='ray.rpc.NodeInfoGcsService.RegisterNode',
    index=0,
    containing_service=None,
    input_type=_REGISTERNODEREQUEST,
    output_type=_REGISTERNODEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnregisterNode',
    full_name='ray.rpc.NodeInfoGcsService.UnregisterNode',
    index=1,
    containing_service=None,
    input_type=_UNREGISTERNODEREQUEST,
    output_type=_UNREGISTERNODEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllNodeInfo',
    full_name='ray.rpc.NodeInfoGcsService.GetAllNodeInfo',
    index=2,
    containing_service=None,
    input_type=_GETALLNODEINFOREQUEST,
    output_type=_GETALLNODEINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInternalConfig',
    full_name='ray.rpc.NodeInfoGcsService.GetInternalConfig',
    index=3,
    containing_service=None,
    input_type=_GETINTERNALCONFIGREQUEST,
    output_type=_GETINTERNALCONFIGREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODEINFOGCSSERVICE)

DESCRIPTOR.services_by_name['NodeInfoGcsService'] = _NODEINFOGCSSERVICE


_HEARTBEATINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='HeartbeatInfoGcsService',
  full_name='ray.rpc.HeartbeatInfoGcsService',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=10190,
  serialized_end=10366,
  methods=[
  _descriptor.MethodDescriptor(
    name='ReportHeartbeat',
    full_name='ray.rpc.HeartbeatInfoGcsService.ReportHeartbeat',
    index=0,
    containing_service=None,
    input_type=_REPORTHEARTBEATREQUEST,
    output_type=_REPORTHEARTBEATREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CheckAlive',
    full_name='ray.rpc.HeartbeatInfoGcsService.CheckAlive',
    index=1,
    containing_service=None,
    input_type=_CHECKALIVEREQUEST,
    output_type=_CHECKALIVEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HEARTBEATINFOGCSSERVICE)

DESCRIPTOR.services_by_name['HeartbeatInfoGcsService'] = _HEARTBEATINFOGCSSERVICE


_OBJECTINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='ObjectInfoGcsService',
  full_name='ray.rpc.ObjectInfoGcsService',
  file=DESCRIPTOR,
  index=4,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=10369,
  serialized_end=10771,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetObjectLocations',
    full_name='ray.rpc.ObjectInfoGcsService.GetObjectLocations',
    index=0,
    containing_service=None,
    input_type=_GETOBJECTLOCATIONSREQUEST,
    output_type=_GETOBJECTLOCATIONSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllObjectLocations',
    full_name='ray.rpc.ObjectInfoGcsService.GetAllObjectLocations',
    index=1,
    containing_service=None,
    input_type=_GETALLOBJECTLOCATIONSREQUEST,
    output_type=_GETALLOBJECTLOCATIONSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddObjectLocation',
    full_name='ray.rpc.ObjectInfoGcsService.AddObjectLocation',
    index=2,
    containing_service=None,
    input_type=_ADDOBJECTLOCATIONREQUEST,
    output_type=_ADDOBJECTLOCATIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveObjectLocation',
    full_name='ray.rpc.ObjectInfoGcsService.RemoveObjectLocation',
    index=3,
    containing_service=None,
    input_type=_REMOVEOBJECTLOCATIONREQUEST,
    output_type=_REMOVEOBJECTLOCATIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBJECTINFOGCSSERVICE)

DESCRIPTOR.services_by_name['ObjectInfoGcsService'] = _OBJECTINFOGCSSERVICE


_TASKINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='TaskInfoGcsService',
  full_name='ray.rpc.TaskInfoGcsService',
  file=DESCRIPTOR,
  index=5,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=10774,
  serialized_end=11173,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddTask',
    full_name='ray.rpc.TaskInfoGcsService.AddTask',
    index=0,
    containing_service=None,
    input_type=_ADDTASKREQUEST,
    output_type=_ADDTASKREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTask',
    full_name='ray.rpc.TaskInfoGcsService.GetTask',
    index=1,
    containing_service=None,
    input_type=_GETTASKREQUEST,
    output_type=_GETTASKREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddTaskLease',
    full_name='ray.rpc.TaskInfoGcsService.AddTaskLease',
    index=2,
    containing_service=None,
    input_type=_ADDTASKLEASEREQUEST,
    output_type=_ADDTASKLEASEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTaskLease',
    full_name='ray.rpc.TaskInfoGcsService.GetTaskLease',
    index=3,
    containing_service=None,
    input_type=_GETTASKLEASEREQUEST,
    output_type=_GETTASKLEASEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AttemptTaskReconstruction',
    full_name='ray.rpc.TaskInfoGcsService.AttemptTaskReconstruction',
    index=4,
    containing_service=None,
    input_type=_ATTEMPTTASKRECONSTRUCTIONREQUEST,
    output_type=_ATTEMPTTASKRECONSTRUCTIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TASKINFOGCSSERVICE)

DESCRIPTOR.services_by_name['TaskInfoGcsService'] = _TASKINFOGCSSERVICE


_STATSGCSSERVICE = _descriptor.ServiceDescriptor(
  name='StatsGcsService',
  full_name='ray.rpc.StatsGcsService',
  file=DESCRIPTOR,
  index=6,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=11176,
  serialized_end=11362,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddProfileData',
    full_name='ray.rpc.StatsGcsService.AddProfileData',
    index=0,
    containing_service=None,
    input_type=_ADDPROFILEDATAREQUEST,
    output_type=_ADDPROFILEDATAREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllProfileInfo',
    full_name='ray.rpc.StatsGcsService.GetAllProfileInfo',
    index=1,
    containing_service=None,
    input_type=_GETALLPROFILEINFOREQUEST,
    output_type=_GETALLPROFILEINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATSGCSSERVICE)

DESCRIPTOR.services_by_name['StatsGcsService'] = _STATSGCSSERVICE


_WORKERINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='WorkerInfoGcsService',
  full_name='ray.rpc.WorkerInfoGcsService',
  file=DESCRIPTOR,
  index=7,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=11365,
  serialized_end=11722,
  methods=[
  _descriptor.MethodDescriptor(
    name='ReportWorkerFailure',
    full_name='ray.rpc.WorkerInfoGcsService.ReportWorkerFailure',
    index=0,
    containing_service=None,
    input_type=_REPORTWORKERFAILUREREQUEST,
    output_type=_REPORTWORKERFAILUREREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkerInfo',
    full_name='ray.rpc.WorkerInfoGcsService.GetWorkerInfo',
    index=1,
    containing_service=None,
    input_type=_GETWORKERINFOREQUEST,
    output_type=_GETWORKERINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllWorkerInfo',
    full_name='ray.rpc.WorkerInfoGcsService.GetAllWorkerInfo',
    index=2,
    containing_service=None,
    input_type=_GETALLWORKERINFOREQUEST,
    output_type=_GETALLWORKERINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddWorkerInfo',
    full_name='ray.rpc.WorkerInfoGcsService.AddWorkerInfo',
    index=3,
    containing_service=None,
    input_type=_ADDWORKERINFOREQUEST,
    output_type=_ADDWORKERINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WORKERINFOGCSSERVICE)

DESCRIPTOR.services_by_name['WorkerInfoGcsService'] = _WORKERINFOGCSSERVICE


_PLACEMENTGROUPINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='PlacementGroupInfoGcsService',
  full_name='ray.rpc.PlacementGroupInfoGcsService',
  file=DESCRIPTOR,
  index=8,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=11725,
  serialized_end=12364,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreatePlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.CreatePlacementGroup',
    index=0,
    containing_service=None,
    input_type=_CREATEPLACEMENTGROUPREQUEST,
    output_type=_CREATEPLACEMENTGROUPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemovePlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.RemovePlacementGroup',
    index=1,
    containing_service=None,
    input_type=_REMOVEPLACEMENTGROUPREQUEST,
    output_type=_REMOVEPLACEMENTGROUPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.GetPlacementGroup',
    index=2,
    containing_service=None,
    input_type=_GETPLACEMENTGROUPREQUEST,
    output_type=_GETPLACEMENTGROUPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNamedPlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.GetNamedPlacementGroup',
    index=3,
    containing_service=None,
    input_type=_GETNAMEDPLACEMENTGROUPREQUEST,
    output_type=_GETNAMEDPLACEMENTGROUPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllPlacementGroup',
    full_name='ray.rpc.PlacementGroupInfoGcsService.GetAllPlacementGroup',
    index=4,
    containing_service=None,
    input_type=_GETALLPLACEMENTGROUPREQUEST,
    output_type=_GETALLPLACEMENTGROUPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitPlacementGroupUntilReady',
    full_name='ray.rpc.PlacementGroupInfoGcsService.WaitPlacementGroupUntilReady',
    index=5,
    containing_service=None,
    input_type=_WAITPLACEMENTGROUPUNTILREADYREQUEST,
    output_type=_WAITPLACEMENTGROUPUNTILREADYREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLACEMENTGROUPINFOGCSSERVICE)

DESCRIPTOR.services_by_name['PlacementGroupInfoGcsService'] = _PLACEMENTGROUPINFOGCSSERVICE


_INTERNALKVGCSSERVICE = _descriptor.ServiceDescriptor(
  name='InternalKVGcsService',
  full_name='ray.rpc.InternalKVGcsService',
  file=DESCRIPTOR,
  index=9,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=12367,
  serialized_end=12786,
  methods=[
  _descriptor.MethodDescriptor(
    name='InternalKVGet',
    full_name='ray.rpc.InternalKVGcsService.InternalKVGet',
    index=0,
    containing_service=None,
    input_type=_INTERNALKVGETREQUEST,
    output_type=_INTERNALKVGETREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InternalKVPut',
    full_name='ray.rpc.InternalKVGcsService.InternalKVPut',
    index=1,
    containing_service=None,
    input_type=_INTERNALKVPUTREQUEST,
    output_type=_INTERNALKVPUTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InternalKVDel',
    full_name='ray.rpc.InternalKVGcsService.InternalKVDel',
    index=2,
    containing_service=None,
    input_type=_INTERNALKVDELREQUEST,
    output_type=_INTERNALKVDELREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InternalKVExists',
    full_name='ray.rpc.InternalKVGcsService.InternalKVExists',
    index=3,
    containing_service=None,
    input_type=_INTERNALKVEXISTSREQUEST,
    output_type=_INTERNALKVEXISTSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InternalKVKeys',
    full_name='ray.rpc.InternalKVGcsService.InternalKVKeys',
    index=4,
    containing_service=None,
    input_type=_INTERNALKVKEYSREQUEST,
    output_type=_INTERNALKVKEYSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTERNALKVGCSSERVICE)

DESCRIPTOR.services_by_name['InternalKVGcsService'] = _INTERNALKVGCSSERVICE


_NODERESOURCEINFOGCSSERVICE = _descriptor.ServiceDescriptor(
  name='NodeResourceInfoGcsService',
  full_name='ray.rpc.NodeResourceInfoGcsService',
  file=DESCRIPTOR,
  index=10,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=12789,
  serialized_end=13357,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetResources',
    full_name='ray.rpc.NodeResourceInfoGcsService.GetResources',
    index=0,
    containing_service=None,
    input_type=_GETRESOURCESREQUEST,
    output_type=_GETRESOURCESREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateResources',
    full_name='ray.rpc.NodeResourceInfoGcsService.UpdateResources',
    index=1,
    containing_service=None,
    input_type=_UPDATERESOURCESREQUEST,
    output_type=_UPDATERESOURCESREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteResources',
    full_name='ray.rpc.NodeResourceInfoGcsService.DeleteResources',
    index=2,
    containing_service=None,
    input_type=_DELETERESOURCESREQUEST,
    output_type=_DELETERESOURCESREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllAvailableResources',
    full_name='ray.rpc.NodeResourceInfoGcsService.GetAllAvailableResources',
    index=3,
    containing_service=None,
    input_type=_GETALLAVAILABLERESOURCESREQUEST,
    output_type=_GETALLAVAILABLERESOURCESREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportResourceUsage',
    full_name='ray.rpc.NodeResourceInfoGcsService.ReportResourceUsage',
    index=4,
    containing_service=None,
    input_type=_REPORTRESOURCEUSAGEREQUEST,
    output_type=_REPORTRESOURCEUSAGEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllResourceUsage',
    full_name='ray.rpc.NodeResourceInfoGcsService.GetAllResourceUsage',
    index=5,
    containing_service=None,
    input_type=_GETALLRESOURCEUSAGEREQUEST,
    output_type=_GETALLRESOURCEUSAGEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NODERESOURCEINFOGCSSERVICE)

DESCRIPTOR.services_by_name['NodeResourceInfoGcsService'] = _NODERESOURCEINFOGCSSERVICE

# @@protoc_insertion_point(module_scope)
